-------------------------------------------------------------------------------
-- Title      : Reset module
-- Project    : 
-------------------------------------------------------------------------------
-- File       : reset.vhd
-- Author     :   <otger@PWOTGER>
-- Company    : 
-- Created    : 2008-12-09
-- Last update: 2009-01-22
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: simple reset logic. When a reset is issued from SW (slink) or
-- HW(pushbutton) it sets reset (and reset_n) for 1us. It is intended that this
-- reset is used by all MCB FW.
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-12-09  1.0      otger   Created
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;

entity McbFullReset is
  
  generic (
    pixResetLength : integer := 80000;  -- 40 ticks of sysClk = 1 us
    seqResetLength : integer := 80);      

  port (
    sysClk      : in  std_logic;
    resetInSw_n : in  std_logic;
    resetInHw_n : in  std_logic;
    seqResetOut : out std_logic;
    pixResetOut : out std_logic);

end McbFullReset;

architecture leia of McbFullReset is
  signal resetIn_n     : std_logic;
--  signal tmpResetOut_n : std_logic;
begin  -- leia

  resetIn_n <= resetInHw_n and resetInSw_n;

  seqReset : process (sysClk, resetIn_n)
    variable resetCounter : integer;
  begin  -- process seqReset
    if resetIn_n = '0' then             -- asynchronous reset (active low)
      resetCounter := 0;
      seqResetOut  <= '1';
      pixResetOut  <= '1';
    elsif sysClk'event and sysClk = '1' then  -- rising clock edge
      if ((resetCounter < pixResetLength) or
          (resetCounter < seqResetLength)) then
        -- Pixel reset
        if resetCounter < pixResetLength then
          pixResetOut <= '1';
        else
          pixResetOut <= '0';
        end if;
        --Sequencer reset
        if resetCounter < seqResetLength then
          seqResetOut <= '1';
        else
          seqResetOut <= '0';
        end if;
        --update counter
        resetCounter := resetCounter + 1;
      else
        seqResetOut <= '0';
        pixResetOut <= '0';
      end if;
    end if;
  end process seqReset;
  

end leia;
