-------------------------------------------------------------------------------
-- Title      : MCBFull
-- Project    : 
-------------------------------------------------------------------------------
-- File       : mcbFull.vhd
-- Author     :   <otger@WWOTGER>
-- Company    : 
-- Created    : 2008-01-23
-- Last update: 2009-01-23
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: Top of new MCB fpga
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-01-23  1.0      otger   Created
-- 2008-12-08           otger   Changed pin reset_n by resetIn_n
--                              Added reset module
--                              Removed rst_n pin
-------------------------------------------------------------------------------


library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;
-- synopsys translate_off
library UNISIM;
use UNISIM.Vcomponents.all;
-- synopsys translate_on

entity mcbFull is
  
  port (
    sysclk    : in    std_logic;
    dq        : inout std_logic;
    led_seq   : out   std_logic;
    temp_sclk : out   std_logic;
    temp_dout : in    std_logic;
    temp_din  : out   std_logic;

    ra_link_n  : out std_logic;
    program_n  : out std_logic;
    fpga_ctl_6 : out std_logic;
    tp_11      : out std_logic;
    tp_12      : out std_logic;
    tp_13      : out std_logic;
    tp_14      : out std_logic;
    tp_19      : out std_logic;
    tp_20      : out std_logic;
    tp_21      : out std_logic;
    tp_22      : in  std_logic;

    board_slct_n : out   std_logic_vector(8 downto 2);
    seq_mode     : out   std_logic_vector(1 downto 0);
    dev_addr     : out   std_logic_vector(5 downto 0);  -- modified, it was <4..0>
    seq_data     : out   std_logic_vector(31 downto 0);
    clk2         : out   std_logic;
    clk3         : out   std_logic;
    clk4         : out   std_logic;
    clk5         : out   std_logic;
    clk6         : out   std_logic;
    clk7         : out   std_logic;
    clk8         : out   std_logic;
    sync_in      : in    std_logic;
    sync_out     : out   std_logic;
    start_exp    : out   std_logic;
    pix_data     : in    std_logic_vector(47 downto 0);
    pipe_req_n   : in    std_logic_vector(6 downto 0);
    pipe_wrt_n   : in    std_logic;
    led_fib      : out   std_logic;
    clk1f0       : out   std_logic;
    clk1f1       : out   std_logic;
    clk2f0       : out   std_logic;
    clk2f1       : out   std_logic;
    scl          : out   std_logic;
    sda          : inout std_logic;
    exdat_in     : in    std_logic;
    exdat_out    : out   std_logic;
    uclk         : out   std_logic;
    ud           : out   std_logic_vector(31 downto 0);
    lrl          : in    std_logic_vector(3 downto 0);
    lff_n        : in    std_logic;
    utest_n      : out   std_logic;
    ldown_n      : in    std_logic;
    uwen_n       : out   std_logic;
    uctrl_n      : out   std_logic;
    ureset_n     : out   std_logic;

    delChipClk : out std_logic;
    delChipD : out std_logic;
    delChipE : out std_logic;

    ack_n : in std_logic_vector(8 downto 2);

    resetInHw_n : in std_logic;         -- board reset

    spr       : inout std_logic_vector(8 downto 0);

    temp_cs    : out std_logic
    );
end mcbFull;

architecture behavioral of mcbFull is

  -----------------------------------------------------------------------------
  -- Components
  -----------------------------------------------------------------------------
  -- Reset
  component McbFullReset
    generic (
      pixResetLength : integer;
      seqResetLength : integer);
    port (
      sysClk      : in  std_logic;
      resetInSw_n : in  std_logic;
      resetInHw_n : in  std_logic;
      seqResetOut : out std_logic;
      pixResetOut : out std_logic);
  end component;

  -- Top pix
  component topPixFpga
    port (
      reset           : in    std_logic;
      dataRdy         : out   std_logic;
      dataOut         : out   std_logic_vector(31 downto 0);
      dataRead        : in    std_logic;
      dataIn          : in    std_logic_vector(31 downto 0);
      cmdRdy          : in    std_logic;
      seqDataReq      : in    std_logic;
      syncIn          : in    std_logic;
      fpga_ctl_2      : in    std_logic;
      pix_data        : in    std_logic_vector(47 downto 0);
      pipe_req_n      : in    std_logic_vector(6 downto 0);
      pipe_wrt_n      : in    std_logic;
      fpga_ctl_1      : in    std_logic;
      sysclk          : in    std_logic;
      led_fib         : out   std_logic;
      clk1f0          : out   std_logic;
      clk1f1          : out   std_logic;
      clk2f0          : out   std_logic;
      clk2f1          : out   std_logic;
--      TESTIN1         : in    std_logic;
--      TESTIN2         : in    std_logic;
--      TESTOUT1        : out   std_logic;
--      TESTOUT2        : out   std_logic;
--      TESTOUT3        : out   std_logic;
--      TESTOUT4        : out   std_logic;
--      TESTOUT5        : out   std_logic;
--      TESTOUT6        : out   std_logic;
--      TESTOUT7        : out   std_logic;
      scl             : out   std_logic;
      sda             : inout std_logic;
      exdat_in        : in    std_logic;
      exdat_out       : out   std_logic;
      uclk            : out   std_logic;
      ud              : out   std_logic_vector(31 downto 0);
      lrl             : in    std_logic_vector(3 downto 0);
      lff_n           : in    std_logic;
      utest_n         : out   std_logic;
      ldown_n         : in    std_logic;
      uwen_n          : out   std_logic;
      uctrl_n         : out   std_logic;
      slinkResetOut_n : out   std_logic;
      ureset_n        : out   std_logic);
  end component;

  -- Former Sequencer Fpga  Top
  component topSeqFpga
    port (
      reset      : in    std_logic;
      SYNC_IN    : in    std_logic;
      SYSCLK     : in    std_logic;
      TEMP_DOUT  : in    std_logic;
      BRD_SLCT_N : out   std_logic_vector (8 downto 2);
      CLK2       : out   std_logic;
      CLK3       : out   std_logic;
      CLK4       : out   std_logic;
      CLK5       : out   std_logic;
      CLK6       : out   std_logic;
      CLK7       : out   std_logic;
      CLK8       : out   std_logic;
      DEV_ADDR   : out   std_logic_vector (4 downto 0);
      FPGA_CTL_1 : out   std_logic;
      FPGA_CTL_2 : out   std_logic;
      FPGA_CTL_6 : out   std_logic;
      LED_SEQ    : out   std_logic;
      PROGRAM_N  : out   std_logic;
      RA_LINK_N  : out   std_logic;
      SEQ_DATA   : out   std_logic_vector (31 downto 0);
      SEQ_MODE   : out   std_logic_vector (1 downto 0);
      START_EXP  : out   std_logic;
      SYNC_OUT   : out   std_logic;
      TEMP_DIN   : out   std_logic;
      TEMP_SCLK  : out   std_logic;
--      TESTIN1    : in    std_logic;
--      TESTIN2    : in    std_logic;
--      TESTOUT1   : out   std_logic;
--      TESTOUT2   : out   std_logic;
--      TESTOUT3   : out   std_logic;
--      TESTOUT4   : out   std_logic;
      DQ         : inout std_logic;
      delChipClk : out std_logic;
      delChipD   : out std_logic;
      delChipE   : out std_logic;
      dataRdy    : in    std_logic;
      dataIn     : in    std_logic_vector(31 downto 0);
      dataRead   : out   std_logic;
      dataOut    : out   std_logic_vector(31 downto 0);
      cmdRdy     : out   std_logic;
      seqDataReq : out   std_logic;
      syncOut    : out   std_logic);
  end component;

  component BUF
    port (I : in  std_logic;
          O : out std_logic);
  end component;
  -----------------------------------------------------------------------------
  -- Signals
  -----------------------------------------------------------------------------
  signal fpga_ctl_1         : std_logic;
  signal fpga_ctl_1_delayed : std_logic;
  signal fpga_ctl_2         : std_logic;

  signal fpgaDataRdy    : std_logic;
  signal fpgaDataP2S    : std_logic_vector(31 downto 0);
  signal fpgaDataRead   : std_logic;
  signal fpgaDataS2P    : std_logic_vector(31 downto 0);
  signal fpgaCmdRdy     : std_logic;
  signal fpgaSeqDataReq : std_logic;
  signal fpgaSyncS2P    : std_logic;

  signal sysclk_int    : std_logic;
  signal double_sysclk : std_logic;

  signal resetSw_n : std_logic;

  signal seqResetOut : std_logic;
  signal pixResetOut : std_logic;


  signal delChipE_tmp : std_logic;

  signal sync_out_tmp : std_logic;

  
begin  -- behavioral


  sync_out <= sync_out_tmp;
  dev_addr(5) <= '0';
  temp_cs <= '0';
  

  topSeqFpga_1 : topSeqFpga
    port map (
      reset      => seqResetOut,
      SYNC_IN    => sync_in,    --
      SYSCLK     => sysclk_int,         --
      TEMP_DOUT  => temp_dout,          --
      BRD_SLCT_N => board_slct_n,       --
      CLK2       => clk2,               --
      CLK3       => clk3,               --
      CLK4       => clk4,               --
      CLK5       => clk5,               --
      CLK6       => clk6,               --
      CLK7       => clk7,               --
      CLK8       => clk8,               --
      DEV_ADDR   => dev_addr(4 downto 0),           --
      FPGA_CTL_1 => fpga_ctl_1,         --
      FPGA_CTL_2 => fpga_ctl_2,         --
      FPGA_CTL_6 => fpga_ctl_6,         --
      LED_SEQ    => led_seq,            --
      PROGRAM_N  => program_n,          --
      RA_LINK_N  => ra_link_n,          --
      SEQ_DATA   => seq_data,           --
      SEQ_MODE   => seq_mode,           --
      START_EXP  => start_exp,          --
      SYNC_OUT   => sync_out_tmp,    --
      TEMP_DIN   => temp_din,           --
      TEMP_SCLK  => temp_sclk,          --

--      TESTIN1  => '0',
--      TESTIN2  => '0',
--      TESTOUT1 => tp_19,                --

      DQ => dq,                         --

      delChipClk => delChipClk,
      delChipD => delChipD,
      delChipE => delChipE_tmp,

      dataRdy    => fpgaDataRdy,
      dataOut    => fpgaDataS2P,
      dataRead   => fpgaDataRead,
      dataIn     => fpgaDataP2S,
      cmdRdy     => fpgaCmdRdy,
      seqDataReq => fpgaSeqDataReq,
      syncOut     => fpgaSyncS2P
      );                                --

  delChipE <= delChipE_tmp;

  -----------------------------------------------------------------------------
  -- Fpga_ctl_1
  -- When joining pixel and sequencer fpga's fpga_ctl_1 was one cycle forward
  -- With this FF fpga_ctl_1 is issued on third cycle of a read in backplane
  -----------------------------------------------------------------------------
  p_del_ctl_1 : process (seqResetOut, sysclk)
  begin  -- process p_del_ctl_1
    if seqResetOut = '1' then           -- asynchronous reset (active High)
      fpga_ctl_1_delayed <= '0';
    elsif sysclk'event and sysclk = '1' then  -- rising clock edge
      fpga_ctl_1_delayed <= fpga_ctl_1;
    end if;
  end process p_del_ctl_1;


  -----------------------------------------------------------------------------
  -- Top pix fpga
  -----------------------------------------------------------------------------
  topPixFpga_1 : topPixFpga
    port map (
      reset           => pixResetOut,
      dataRdy         => fpgaDataRdy,
      dataOut         => fpgaDataP2S,
      dataRead        => fpgaDataRead,
      dataIn          => fpgaDataS2P,
      cmdRdy          => fpgaCmdRdy,
      seqDataReq      => fpgaSeqDataReq,
      syncIn          => fpgaSyncS2P,
      fpga_ctl_2      => fpga_ctl_2,          --
      pix_data        => pix_data,            --
      pipe_req_n      => pipe_req_n,          --
      pipe_wrt_n      => pipe_wrt_n,          --
      fpga_ctl_1      => fpga_ctl_1_delayed,  --
      sysclk          => sysclk_int,          --
      led_fib         => led_fib,             --
      clk1f0          => clk1f0,              --
      clk1f1          => clk1f1,              --
      clk2f0          => clk2f0,              --
      clk2f1          => clk2f1,              --
--      TESTIN1         => tp_22,               -- ext reset
--      TESTIN2         => '0',
      scl             => scl,                 --
      sda             => sda,                 --
      exdat_in        => exdat_in,            --
      exdat_out       => exdat_out,           --
      uclk            => uclk,                --
      ud              => ud,                  --
      lrl             => lrl,                 --
      lff_n           => lff_n,               --
      utest_n         => utest_n,             --
      ldown_n         => ldown_n,             --
      uwen_n          => uwen_n,              --
      uctrl_n         => uctrl_n,             --
      slinkResetOut_n => resetSw_n,
      ureset_n        => ureset_n);           --


  sysclk_int <= sysclk;


  -----------------------------------------------------------------------------
  -- Test points
  -----------------------------------------------------------------------------
  
  tp_11 <= '0';
  tp_12 <= '0';
  tp_13 <= '0';
  tp_14 <= sync_out_tmp;
  tp_19 <= '0';
  tp_20 <= '0';
  tp_21 <= '0';


  -----------------------------------------------------------------------------
  -- Reset module
  -- It accepts resets from SW and HW and generates a reset for all the MCB FW
  -- that lasts 1us (if resetLength = 40)
  -----------------------------------------------------------------------------

 
  reset_1 : McbFullReset
    generic map (
      pixResetLength => 80,
      seqResetLength => 80)
    port map (
      sysClk      => sysClk,
      resetInSw_n => resetSw_n,
      resetInHw_n => tp_22,
      seqResetOut => seqResetOut,
      pixResetOut => pixResetOut);

end behavioral;
