-------------------------------------------------------------------------------
-- Title      : PackagePixel
-- Project    : 
-------------------------------------------------------------------------------
-- File       : PackagePixel.vhd
-- Author     :   <otger@WWOTGER>
-- Company    : 
-- Created    : 2008-01-16
-- Last update: 2008-12-23
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: Package for all former Pixel FPGA components
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-01-16  1.0      otger   Created
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;


-------------------------------------------------------------------------------

package PackagePixel is

  component PIXEL_DATA_FIFO_V461
    port (
      CLK            : in  std_logic;
      RST            : in  std_logic;
      DATA_IN        : in  std_logic_vector(47 downto 0);
      DATA_OUT       : out std_logic_vector(31 downto 0);
      SEQ_WRT_N      : in  std_logic;
      PIPELINE_REQ_N : in  std_logic_vector(6 downto 0);
      PIPELINE_WRT_N : in  std_logic;
      RD             : in  std_logic;
      DBL_WD_XFER    : in  std_logic;
      PIPELINE_ENBL  : in  std_logic;
      DATA_RDY       : out std_logic;
      SYNC_OUT       : out std_logic;
      SIM_ENABLE     : in  std_logic;
      SIM_PIXROWS    : in  std_logic_vector(15 downto 0);
      SIM_PIXCOLS    : in  std_logic_vector(15 downto 0);
      SIM_PIXTIME    : in  std_logic_vector(7 downto 0);
      SIM_CHANNELS   : in  std_logic_vector(6 downto 0);
      SIM_DELAY      : in  std_logic_vector(7 downto 0);
      SIM_TRIGGER    : in  std_logic);
  end component;

  component PixCmdDecodeV461
    port (
      SYSCLK       : in    std_logic;
      RESET        : in    std_logic;
      CMD_RDY      : in    std_logic;
      CMD_ACK      : out   std_logic;
      CMD_READ     : in    std_logic;
      CMD_DATA     : in    std_logic_vector(31 downto 0);
      ADDRESS      : out   std_logic_vector(6 downto 0);
      REG_DATA     : inout std_logic_vector(15 downto 0);
      DATA_OUT     : out   std_logic_vector(15 downto 0);
      READ_REQ     : out   std_logic;
      READ_ACK     : in    std_logic;
      READ_SYNC    : out   std_logic;
      READ_WRITE_N : inout std_logic;
      CFG_CMD_STB  : out   std_logic;
      ADC_CMD_STB  : out   std_logic;
      MOD_CMD_STB  : out   std_logic;
      DAC_CMD_STB  : out   std_logic;
      SYN_CMD_STB  : out   std_logic;
      CLK_CMD_STB  : out   std_logic;
      FCH_CMD_STB  : out   std_logic;
      LED_CMD_STB  : out   std_logic;
      DBL_WRD_XFER : out   std_logic;
      SIM_ENABLE   : out   std_logic;
      SIM_PIXROWS  : out   std_logic_vector(15 downto 0);
      SIM_PIXCOLS  : out   std_logic_vector(15 downto 0);
      SIM_PIXTIME  : out   std_logic_vector(7 downto 0);
      SIM_CHANNELS : out   std_logic_vector(6 downto 0);
      SIM_DELAY    : out   std_logic_vector(7 downto 0));
  end component;

  component PixDataMuxV40
    port (
      PIX_DATA_IN   : in  std_logic_vector(31 downto 0);
      PIX_DATA_REQ  : in  std_logic;
      PIX_DATA_ACK  : out std_logic;
      PIX_DATA_SYNC : in  std_logic;
      SEQ_DATA_IN   : in  std_logic_vector(31 downto 0);
      SEQ_DATA_REQ  : in  std_logic;
      SEQ_DATA_ACK  : out std_logic;
      SEQ_DATA_SYNC : in  std_logic;
      LOC_DATA_IN   : in  std_logic_vector(15 downto 0);
      LOC_DATA_REQ  : in  std_logic;
      LOC_DATA_ACK  : out std_logic;
      LOC_DATA_SYNC : in  std_logic;
      DATA_OUT      : out std_logic_vector(31 downto 0);
      DATA_WR       : out std_logic;
      DATA_SYNC     : out std_logic;
      DATA_BUSY     : in  std_logic);
  end component;

  component SLinkIfc
    port (
      DATA_IN   : in  std_logic_vector (31 downto 0);
      DATA_READ : in  std_logic;
      DATA_WRT  : in  std_logic;
      LDOWN_N   : in  std_logic;
      LFF_N     : in  std_logic;
      LRL       : in  std_logic_vector (3 downto 0);
      RESET_IN  : in  std_logic;
      SYNC_IN   : in  std_logic;
      SYSCLK    : in  std_logic;
      DATA_BUSY : out std_logic;
      DATA_OUT  : out std_logic_vector (31 downto 0);
      DATA_RDY  : out std_logic;
      RESET_OUT : out std_logic;
      UCLK      : out std_logic;
      UCTRL_N   : out std_logic;
      UD        : out std_logic_vector (31 downto 0);
      UTEST_N   : out std_logic;
      URESET_N  : out std_logic;
      UWEN_N    : out std_logic);
  end component;

  component ExDataLatchV40
    port (
      SYSCLK    : in    std_logic;
      EXDAT_CS  : in    std_logic;
      READ      : in    std_logic;
      DATA_IN   : in    std_logic;
      DATA_OUT  : inout std_logic_vector(15 downto 0);
      EXDAT_OUT : out   std_logic;
      EXDAT_IN  : in    std_logic);
  end component;

  component SerConfigIfcV42
    port (
      SYSCLK    : in    std_logic;
      RESET     : in    std_logic;
      READ      : in    std_logic;
      FETCH_CS  : in    std_logic;
      SRCFG_CS  : in    std_logic;
      WRITE_EN  : in    std_logic;
      DATA_IN   : in    std_logic_vector(15 downto 0);
      DATA_OUT  : inout std_logic_vector(15 downto 0);
      DATA_ADDR : in    std_logic_vector(6 downto 0);
      SCL       : out   std_logic;
      SDA_IN    : in    std_logic;
      SDA_OUT   : out   std_logic;
      SDA_ENAB  : out   std_logic;
      PING      : out   std_logic;
      PONG      : out   std_logic);
  end component;

  component ClkCntrlDecodeV40
    port (
      SYSCLK   : in    std_logic;
      CLK_CS   : in    std_logic;
      READ     : in    std_logic;
      DATA_IN  : in    std_logic_vector(7 downto 0);
      DATA_OUT : inout std_logic_vector(15 downto 0);
      CLK1D0   : out   std_logic;
      CLK1D1   : out   std_logic;
      CLK1D2   : out   std_logic;
      CLK1D3   : out   std_logic;
      CLK2D0   : out   std_logic;
      CLK2D1   : out   std_logic;
      CLK2D2   : out   std_logic;
      CLK2D3   : out   std_logic);
  end component;

  component LedLatchV40Pix
    port (
      SYSCLK       : in    std_logic;
      LED_CS       : in    std_logic;
      READ         : in    std_logic;
      RESET : in    std_logic;
      LED_SRC_1    : in    std_logic;
      LED_SRC_2    : in    std_logic;
      LED_SRC_3    : in    std_logic;
      DATA_IN      : in    std_logic_vector(2 downto 0);
      DATA_OUT     : inout std_logic_vector(15 downto 0);
      LED_EN       : out   std_logic);
  end component;
  
  
end PackagePixel;
