----------------------------------------------------------------------------------
-- Company: 
-- Engineer: 
-- 
-- Create Date:    23:01:36 09/12/2006 
-- Design Name: 
-- Module Name:    slink_fifo - Behavioral 
-- Project Name: 
-- Target Devices: 
-- Tool versions: 
-- Description: 
--
-- Dependencies: 
--
-- Revision: 
-- Revision 0.01 - File Created
-- Additional Comments: 
--
----------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.all;
--use IEEE.STD_LOGIC_UNSIGNED.all;
use IEEE.numeric_std.all;

---- Uncomment the following library declaration if instantiating
---- any Xilinx primitives in this code.
--library UNISIM;
--use UNISIM.VComponents.all;

entity slink_fifo is
  generic (
    width  :     integer := 32;
    depth  :     integer := 4
    );
  port (
    clk    : in  std_logic;
    areset : in  std_logic;
    din    : in  std_logic_vector (width-1 downto 0);
    wr     : in  std_logic;
    dout   : out std_logic_vector (width-1 downto 0);
    rd     : in  std_logic;
    empty  : out std_logic;
    full   : out std_logic
    );
end slink_fifo;

architecture a of slink_fifo is
  type mem_element is array (integer range 0 to 2**depth - 1) of std_logic_vector (width-1 downto 0);
  signal ffmem                    : mem_element;
  signal wrpos, rdpos             : std_logic_vector(depth-1 downto 0);  --integer range 0 to 2**depth - 1;
  signal wrpos_plus1, wrpos_plus2 : std_logic_vector(depth-1 downto 0);  --integer range 0 to 2**depth - 1;
  signal rdpos_plus1              : std_logic_vector(depth-1 downto 0);  --integer range 0 to 2**depth - 1;
  signal int_full, int_empty      : std_logic;
  signal memof, int_wr, int_rd    : std_logic;
  signal reg_empty                : std_logic;
  signal dout_int                 : std_logic_vector(width-1 downto 0);
-- signal ird, ord : std_logic := 0;

begin

  rdpos_plus1 <= std_logic_vector(unsigned(rdpos) + 1);
  wrpos_plus1 <= std_logic_vector(unsigned(wrpos) + 1);
  wrpos_plus2 <= std_logic_vector(unsigned(wrpos) + 2);

  int_wr <= wr and (not int_full);
  int_rd <= (rd or reg_empty) and (not int_empty);
  full   <= int_full;
  empty  <= reg_empty;

  preread : process (clk, areset)
  begin  -- process preread
    if areset = '0' then                -- asynchronous reset (active high)
      reg_empty <= '1';
    elsif clk'event and clk = '1' then  -- rising clock edge
      reg_empty <= int_empty and (reg_empty or rd);
    end if;
  end process preread;

  overflow : process (clk, areset)
  begin  -- process overflow
    if areset = '0' then                -- asynchronous reset (active high)
      memof   <= '0';
    elsif clk'event and clk = '1' then  -- rising clock edge
      if (wrpos_plus2 = rdpos) and (int_wr = '1') then
        memof <= '1';
      elsif (wrpos /= rdpos) and (int_rd = '1') then
        memof <= '0';
      end if;
    end if;
  end process overflow;

  fullflag : process (clk, areset)
  begin  -- process fullflag
    if areset = '0' then                -- asynchronous reset (active high)
      int_full   <= '0';
    elsif clk'event and clk = '1' then  -- rising clock edge
      if ((wrpos_plus1 = rdpos) and (memof = '1')) and (int_wr = '1') and (int_rd = '0') then
        int_full <= '1';
      elsif ((wrpos_plus1 /= rdpos) or (memof = '0')) and (int_wr = '0') and (int_rd = '1') then
        int_full <= '0';
      end if;
    end if;
  end process fullflag;

  emptyflag : process (clk, areset)
  begin  -- process emptyflag
    if areset = '0' then                -- asynchronous reset (active high)
      int_empty   <= '1';
    elsif clk'event and clk = '1' then  -- rising clock edge
      if ((wrpos /= rdpos_plus1) or (memof = '1')) and (int_wr = '1') and (int_rd = '0') then
        int_empty <= '0';
      elsif ((wrpos = rdpos_plus1) and (memof = '0')) and (int_wr = '0') and (int_rd = '1') then
        int_empty <= '1';

      end if;
    end if;
  end process emptyflag;

  dowrite : process (clk, areset)
  begin  -- process doint_write
    if areset = '0' then                -- asynchronous reset (active high)
      wrpos                                 <= (others => '0');
    elsif clk'event and clk = '1' then  -- rising clock edge
      if int_wr = '1' then
        ffmem (to_integer(unsigned(wrpos))) <= din;
        wrpos                               <= wrpos_plus1;
      else
        wrpos                               <= wrpos;
        ffmem (to_integer(unsigned(wrpos))) <= ffmem (to_integer(unsigned(wrpos)));
      end if;
    end if;
  end process dowrite;
-- dout (31 downto 16) <= std_logic_vector(to_unsigned(wrpos, 8)) & std_logic_vector(to_unsigned(rdpos, 8));
  doread  : process (clk, areset)
  begin  -- process doread
    if areset = '0' then                -- asynchronous reset (active high)
      rdpos                                 <= (others => '0');
--      dout_int                              <= (others => '0');
    elsif clk'event and clk = '1' then  -- rising clock edge
      if int_rd = '1' then
        dout_int (width-1 downto 0)         <= ffmem (to_integer(unsigned(rdpos)))(width-1 downto 0);
        rdpos                               <= rdpos_plus1;
      else
        rdpos                               <= rdpos;
        dout_int                            <= dout_int;
      end if;
    end if;
  end process doread;

  dout <= dout_int;
end a;

