-------------------------------------------------------------------------------
-- Title      : top of former Pixel FPGA
-- Project    : 
-------------------------------------------------------------------------------
-- File       : topPixFpga.vhd
-- Author     :   <otger@ifae.es>
-- Company    : 
-- Created    : 2008-01-16
-- Last update: 2009-03-19
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: 
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-01-16  1.0      otger   Created
-------------------------------------------------------------------------------

library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_arith.all;
use ieee.std_logic_unsigned.all;
use work.PackagePixel.all;

-- synopsys translate_off
library UNISIM;
use UNISIM.Vcomponents.all;
-- synopsys translate_on

entity topPixFpga is
  
  port (
    reset      : in  std_logic;
    -- FPGA interface
    dataRdy    : out std_logic;
    dataOut    : out std_logic_vector(31 downto 0);
    dataRead   : in  std_logic;
    dataIn     : in  std_logic_vector(31 downto 0);
    cmdRdy     : in  std_logic;
    seqDataReq : in  std_logic;
    syncIn     : in  std_logic;

    -- Pixel data fifo
    fpga_ctl_2 : in  std_logic;
    pix_data   : in  std_logic_vector(47 downto 0);
    pipe_req_n : in  std_logic_vector(6 downto 0);
    pipe_wrt_n : in  std_logic;
    fpga_ctl_1 : in  std_logic;
    -- global clock
    sysclk     : in  std_logic;
    -- led latch
    led_fib    : out std_logic;
    -- clk control decode
    clk1f0     : out std_logic;
    clk1f1     : out std_logic;
    clk2f0     : out std_logic;
    clk2f1     : out std_logic;
    -- serial
    scl             : out   std_logic;
    sda             : inout std_logic;
    -- ex data latch
    exdat_in        : in    std_logic;
    exdat_out       : out   std_logic;
    -- SLink
    uclk            : out   std_logic;
    ud              : out   std_logic_vector(31 downto 0);
    lrl             : in    std_logic_vector(3 downto 0);
    lff_n           : in    std_logic;
    utest_n         : out   std_logic;
    ldown_n         : in    std_logic;
    uwen_n          : out   std_logic;
    uctrl_n         : out   std_logic;
    slinkResetOut_n : out   std_logic;
    ureset_n        : out   std_logic);

end topPixFpga;


architecture Behavioral of topPixFpga is
  attribute BOX_TYPE : string;
  component BUFT
    port (I : in  std_logic;
          T : in  std_logic;
          O : out std_logic);
  end component;
  attribute BOX_TYPE of BUFT : component is "BLACK_BOX";

  component IBUF
    port (I : in  std_logic;
          O : out std_logic);
  end component;
  attribute BOX_TYPE of IBUF : component is "BLACK_BOX";

  component OBUF
    port (I : in  std_logic;
          O : out std_logic);
  end component;
  attribute BOX_TYPE of OBUF : component is "BLACK_BOX";

  

  ----------------------------------------------------------------------------
  -- Signals
  ----------------------------------------------------------------------------

--  signal ground : std_logic;
  signal vccNet : std_logic;

  signal BIDIR_DATA_OUT : std_logic_vector (15 downto 0);
  signal BIDIR_READ     : std_logic;

  signal PIX_DAT_FIFO_CLK            : std_logic;
  signal PIX_DAT_FIFO_RST            : std_logic;
  signal PIX_DAT_FIFO_DATA_IN        : std_logic_vector(47 downto 0);
  signal PIX_DAT_FIFO_DATA_OUT       : std_logic_vector(31 downto 0);
  signal PIX_DAT_FIFO_SEQ_WRT_N      : std_logic;
  signal PIX_DAT_FIFO_PIPELINE_REQ_N : std_logic_vector(6 downto 0);
  signal PIX_DAT_FIFO_PIPELINE_WRT_N : std_logic;
  signal PIX_DAT_FIFO_RD             : std_logic;
  signal PIX_DAT_FIFO_DBL_WD_XFER    : std_logic;
  signal PIX_DAT_FIFO_PIPELINE_ENBL  : std_logic;
  signal PIX_DAT_FIFO_DATA_RDY       : std_logic;
  signal PIX_DAT_FIFO_SYNC_OUT       : std_logic;
  signal PIX_DAT_FIFO_SIM_ENABLE     : std_logic;
  signal PIX_DAT_FIFO_SIM_PIXROWS    : std_logic_vector(15 downto 0);
  signal PIX_DAT_FIFO_SIM_PIXCOLS    : std_logic_vector(15 downto 0);
  signal PIX_DAT_FIFO_SIM_PIXTIME    : std_logic_vector(7 downto 0);
  signal PIX_DAT_FIFO_SIM_CHANNELS   : std_logic_vector(6 downto 0);
  signal PIX_DAT_FIFO_SIM_DELAY      : std_logic_vector(7 downto 0);
  signal PIX_DAT_FIFO_SIM_TRIGGER    : std_logic;

  signal PIX_CMD_DEC_SYSCLK       : std_logic;
  signal PIX_CMD_DEC_RESET        : std_logic;
  signal PIX_CMD_DEC_CMD_RDY      : std_logic;
  signal PIX_CMD_DEC_CMD_ACK      : std_logic;
  signal PIX_CMD_DEC_CMD_READ     : std_logic;
  signal PIX_CMD_DEC_CMD_DATA     : std_logic_vector(31 downto 0);
  signal PIX_CMD_DEC_ADDRESS      : std_logic_vector(6 downto 0);
  signal PIX_CMD_DEC_REG_DATA     : std_logic_vector(15 downto 0);
  signal PIX_CMD_DEC_DATA_OUT     : std_logic_vector(15 downto 0);
  signal PIX_CMD_DEC_READ_REQ     : std_logic;
  signal PIX_CMD_DEC_READ_ACK     : std_logic;
  signal PIX_CMD_DEC_READ_SYNC    : std_logic;
  signal PIX_CMD_DEC_READ_WRITE_N : std_logic;
  signal PIX_CMD_DEC_CFG_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_ADC_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_MOD_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_DAC_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_SYN_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_CLK_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_FCH_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_LED_CMD_STB  : std_logic;
  signal PIX_CMD_DEC_DBL_WRD_XFER : std_logic;
  signal PIX_CMD_DEC_SIM_ENABLE   : std_logic;
  signal PIX_CMD_DEC_SIM_PIXROWS  : std_logic_vector(15 downto 0);
  signal PIX_CMD_DEC_SIM_PIXCOLS  : std_logic_vector(15 downto 0);
  signal PIX_CMD_DEC_SIM_PIXTIME  : std_logic_vector(7 downto 0);
  signal PIX_CMD_DEC_SIM_CHANNELS : std_logic_vector(6 downto 0);
  signal PIX_CMD_DEC_SIM_DELAY    : std_logic_vector(7 downto 0);

  signal PIX_DAT_MUX_PIX_DATA_IN   : std_logic_vector(31 downto 0);
  signal PIX_DAT_MUX_PIX_DATA_REQ  : std_logic;
  signal PIX_DAT_MUX_PIX_DATA_ACK  : std_logic;
  signal PIX_DAT_MUX_PIX_DATA_SYNC : std_logic;
  signal PIX_DAT_MUX_SEQ_DATA_IN   : std_logic_vector(31 downto 0);
  signal PIX_DAT_MUX_SEQ_DATA_REQ  : std_logic;
  signal PIX_DAT_MUX_SEQ_DATA_ACK  : std_logic;
  signal PIX_DAT_MUX_SEQ_DATA_SYNC : std_logic;
--  signal PIX_DAT_MUX_LOC_DATA_IN   : std_logic_vector(15 downto 0);
  signal PIX_DAT_MUX_LOC_DATA_REQ  : std_logic;
  signal PIX_DAT_MUX_LOC_DATA_ACK  : std_logic;
  signal PIX_DAT_MUX_LOC_DATA_SYNC : std_logic;
  signal PIX_DAT_MUX_DATA_OUT      : std_logic_vector(31 downto 0);
  signal PIX_DAT_MUX_DATA_WR       : std_logic;
  signal PIX_DAT_MUX_DATA_SYNC     : std_logic;
  signal PIX_DAT_MUX_DATA_BUSY     : std_logic;

  signal SLINK_DATA_IN   : std_logic_vector (31 downto 0);
  signal SLINK_DATA_READ : std_logic;
  signal SLINK_DATA_WRT  : std_logic;
  signal SLINK_LDOWN_N   : std_logic;
  signal SLINK_LFF_N     : std_logic;
  signal SLINK_LRL       : std_logic_vector (3 downto 0);
  signal SLINK_RESET_IN  : std_logic;
  signal SLINK_SYNC_IN   : std_logic;
  signal SLINK_SYSCLK    : std_logic;
  signal SLINK_DATA_BUSY : std_logic;
  signal SLINK_DATA_OUT  : std_logic_vector (31 downto 0);
  signal SLINK_DATA_RDY  : std_logic;
  signal SLINK_RESET_OUT : std_logic;
  signal SLINK_UCLK      : std_logic;
  signal SLINK_UCTRL_N   : std_logic;
  signal SLINK_UD        : std_logic_vector (31 downto 0);
  signal SLINK_UTEST_N   : std_logic;
  signal SLINK_URESET_N  : std_logic;
  signal SLINK_UWEN_N    : std_logic;

  signal EX_DAT_LATCH_SYSCLK    : std_logic;
  signal EX_DAT_LATCH_EXDAT_CS  : std_logic;
  signal EX_DAT_LATCH_READ      : std_logic;
  signal EX_DAT_LATCH_DATA_IN   : std_logic;
  signal EX_DAT_LATCH_DATA_OUT  : std_logic_vector(15 downto 0);
  signal EX_DAT_LATCH_EXDAT_OUT : std_logic;
  signal EX_DAT_LATCH_EXDAT_IN  : std_logic;

  signal SER_CFG_IFC_SYSCLK    : std_logic;
  signal SER_CFG_IFC_RESET     : std_logic;
--  signal SER_CFG_IFC_READ      : std_logic;
  signal SER_CFG_IFC_FETCH_CS  : std_logic;
  signal SER_CFG_IFC_SRCFG_CS  : std_logic;
  signal SER_CFG_IFC_WRITE_EN  : std_logic;
  signal SER_CFG_IFC_DATA_IN   : std_logic_vector(15 downto 0);
--  signal SER_CFG_IFC_DATA_OUT  : std_logic_vector(15 downto 0);
  signal SER_CFG_IFC_DATA_ADDR : std_logic_vector(6 downto 0);
  signal SER_CFG_IFC_SCL       : std_logic;
  signal SER_CFG_IFC_SDA_IN    : std_logic;
  signal SER_CFG_IFC_SDA_OUT   : std_logic;
  signal SER_CFG_IFC_SDA_ENAB  : std_logic;
  signal SER_CFG_IFC_PING      : std_logic;
  signal SER_CFG_IFC_PONG      : std_logic;

  signal CLK_CTRL_DEC_SYSCLK   : std_logic;
  signal CLK_CTRL_DEC_CLK_CS   : std_logic;
  signal CLK_CTRL_DEC_READ     : std_logic;
  signal CLK_CTRL_DEC_DATA_IN  : std_logic_vector(7 downto 0);
  signal CLK_CTRL_DEC_DATA_OUT : std_logic_vector(15 downto 0);
  signal CLK_CTRL_DEC_CLK1D0   : std_logic;
  signal CLK_CTRL_DEC_CLK1D1   : std_logic;
  signal CLK_CTRL_DEC_CLK1D2   : std_logic;
  signal CLK_CTRL_DEC_CLK1D3   : std_logic;
  signal CLK_CTRL_DEC_CLK2D0   : std_logic;
  signal CLK_CTRL_DEC_CLK2D1   : std_logic;
  signal CLK_CTRL_DEC_CLK2D2   : std_logic;
  signal CLK_CTRL_DEC_CLK2D3   : std_logic;

  signal LED_LATCH_SYSCLK       : std_logic;
  signal LED_LATCH_LED_CS       : std_logic;
  signal LED_LATCH_READ         : std_logic;
  signal LED_LATCH_RESET_ACTIVE : std_logic;
  signal LED_LATCH_LED_SRC_1    : std_logic;
  signal LED_LATCH_LED_SRC_2    : std_logic;
  signal LED_LATCH_LED_SRC_3    : std_logic;
  signal LED_LATCH_DATA_IN      : std_logic_vector(2 downto 0);
  signal LED_LATCH_DATA_OUT     : std_logic_vector(15 downto 0);
  signal LED_LATCH_LED_EN       : std_logic;

begin  -- Behavioral

--  ground <= '0';
  vccNet <= '1';

  slinkResetOut_n <= not SLINK_RESET_OUT;

  -----------------------------------------------------------------------------
  -- Component Instances
  -----------------------------------------------------------------------------
  -- Pixel data fifo

  PIXEL_DATA_FIFO_V461_1 : PIXEL_DATA_FIFO_V461
    port map (
      CLK            => PIX_DAT_FIFO_CLK,
      RST            => PIX_DAT_FIFO_RST,
      DATA_IN        => PIX_DAT_FIFO_DATA_IN,
      DATA_OUT       => PIX_DAT_FIFO_DATA_OUT,
      SEQ_WRT_N      => PIX_DAT_FIFO_SEQ_WRT_N,
      PIPELINE_REQ_N => PIX_DAT_FIFO_PIPELINE_REQ_N,
      PIPELINE_WRT_N => PIX_DAT_FIFO_PIPELINE_WRT_N,
      RD             => PIX_DAT_FIFO_RD,
      DBL_WD_XFER    => PIX_DAT_FIFO_DBL_WD_XFER,
      PIPELINE_ENBL  => PIX_DAT_FIFO_PIPELINE_ENBL,
      DATA_RDY       => PIX_DAT_FIFO_DATA_RDY,
      SYNC_OUT       => PIX_DAT_FIFO_SYNC_OUT,
      SIM_ENABLE     => PIX_DAT_FIFO_SIM_ENABLE,
      SIM_PIXROWS    => PIX_DAT_FIFO_SIM_PIXROWS,
      SIM_PIXCOLS    => PIX_DAT_FIFO_SIM_PIXCOLS,
      SIM_PIXTIME    => PIX_DAT_FIFO_SIM_PIXTIME,
      SIM_CHANNELS   => PIX_DAT_FIFO_SIM_CHANNELS,
      SIM_DELAY      => PIX_DAT_FIFO_SIM_DELAY,
      SIM_TRIGGER    => PIX_DAT_FIFO_SIM_TRIGGER);

  PIX_DAT_FIFO_SIM_TRIGGER                <= fpga_ctl_2;
  PIX_DAT_FIFO_DATA_IN(47 downto 0)       <= pix_data(47 downto 0);
  PIX_DAT_FIFO_PIPELINE_REQ_N(6 downto 0) <= pipe_req_n(6 downto 0);
  PIX_DAT_FIFO_PIPELINE_WRT_N             <= pipe_wrt_n;
  PIX_DAT_FIFO_SEQ_WRT_N                  <= fpga_ctl_1;
  PIX_DAT_FIFO_RST                        <= RESET;
  PIX_DAT_FIFO_PIPELINE_ENBL              <= not RESET;
--  PIX_DAT_FIFO_RST                        <= SLINK_RESET_OUT;
--  PIX_DAT_FIFO_PIPELINE_ENBL              <= not SLINK_RESET_OUT;
  PIX_DAT_FIFO_SIM_DELAY(7 downto 0)      <= PIX_CMD_DEC_SIM_DELAY(7 downto 0);
  PIX_DAT_FIFO_SIM_CHANNELS(6 downto 0)   <= PIX_CMD_DEC_SIM_CHANNELS(6 downto 0);
  PIX_DAT_FIFO_SIM_PIXTIME(7 downto 0)    <= PIX_CMD_DEC_SIM_PIXTIME(7 downto 0);
  PIX_DAT_FIFO_SIM_PIXCOLS(15 downto 0)   <= PIX_CMD_DEC_SIM_PIXCOLS(15 downto 0);
  PIX_DAT_FIFO_SIM_PIXROWS(15 downto 0)   <= PIX_CMD_DEC_SIM_PIXROWS(15 downto 0);
  PIX_DAT_FIFO_SIM_ENABLE                 <= PIX_CMD_DEC_SIM_ENABLE;
  PIX_DAT_FIFO_DBL_WD_XFER                <= PIX_CMD_DEC_DBL_WRD_XFER;
  PIX_DAT_FIFO_CLK                        <= SYSCLK;
  PIX_DAT_FIFO_RD                         <= PIX_DAT_MUX_PIX_DATA_ACK;


  -----------------------------------------------------------------------------
  -- Pix Cmd Decode

  PixCmdDecodeV461_1 : PixCmdDecodeV461
    port map (
      SYSCLK       => PIX_CMD_DEC_SYSCLK,
      RESET        => PIX_CMD_DEC_RESET,
      CMD_RDY      => PIX_CMD_DEC_CMD_RDY,
      CMD_ACK      => PIX_CMD_DEC_CMD_ACK,
      CMD_READ     => PIX_CMD_DEC_CMD_READ,
      CMD_DATA     => PIX_CMD_DEC_CMD_DATA,
      ADDRESS      => PIX_CMD_DEC_ADDRESS,
      REG_DATA     => BIDIR_DATA_OUT,
      DATA_OUT     => PIX_CMD_DEC_DATA_OUT,
      READ_REQ     => PIX_CMD_DEC_READ_REQ,
      READ_ACK     => PIX_CMD_DEC_READ_ACK,
      READ_SYNC    => PIX_CMD_DEC_READ_SYNC,
      READ_WRITE_N => BIDIR_READ,
      CFG_CMD_STB  => PIX_CMD_DEC_CFG_CMD_STB,
      ADC_CMD_STB  => PIX_CMD_DEC_ADC_CMD_STB,
      MOD_CMD_STB  => PIX_CMD_DEC_MOD_CMD_STB,
      DAC_CMD_STB  => PIX_CMD_DEC_DAC_CMD_STB,
      SYN_CMD_STB  => PIX_CMD_DEC_SYN_CMD_STB,
      CLK_CMD_STB  => PIX_CMD_DEC_CLK_CMD_STB,
      FCH_CMD_STB  => PIX_CMD_DEC_FCH_CMD_STB,
      LED_CMD_STB  => PIX_CMD_DEC_LED_CMD_STB,
      DBL_WRD_XFER => PIX_CMD_DEC_DBL_WRD_XFER,
      SIM_ENABLE   => PIX_CMD_DEC_SIM_ENABLE,
      SIM_PIXROWS  => PIX_CMD_DEC_SIM_PIXROWS,
      SIM_PIXCOLS  => PIX_CMD_DEC_SIM_PIXCOLS,
      SIM_PIXTIME  => PIX_CMD_DEC_SIM_PIXTIME,
      SIM_CHANNELS => PIX_CMD_DEC_SIM_CHANNELS,
      SIM_DELAY    => PIX_CMD_DEC_SIM_DELAY);

  PIX_CMD_DEC_RESET                 <= RESET;
  PIX_CMD_DEC_CMD_RDY               <= cmdRdy;
  PIX_CMD_DEC_CMD_READ              <= syncIn;
  PIX_CMD_DEC_CMD_DATA <= dataIn;
  PIX_CMD_DEC_SYSCLK                <= SYSCLK;
  PIX_CMD_DEC_READ_ACK              <= PIX_DAT_MUX_LOC_DATA_ACK;

  -----------------------------------------------------------------------------
  -- Pix Data Mux

  PixDataMuxV40_1 : PixDataMuxV40
    port map (
      PIX_DATA_IN   => PIX_DAT_MUX_PIX_DATA_IN,
      PIX_DATA_REQ  => PIX_DAT_MUX_PIX_DATA_REQ,
      PIX_DATA_ACK  => PIX_DAT_MUX_PIX_DATA_ACK,
      PIX_DATA_SYNC => PIX_DAT_MUX_PIX_DATA_SYNC,
      SEQ_DATA_IN   => PIX_DAT_MUX_SEQ_DATA_IN,
      SEQ_DATA_REQ  => PIX_DAT_MUX_SEQ_DATA_REQ,
      SEQ_DATA_ACK  => PIX_DAT_MUX_SEQ_DATA_ACK,
      SEQ_DATA_SYNC => PIX_DAT_MUX_SEQ_DATA_SYNC,
      LOC_DATA_IN   => BIDIR_DATA_OUT,
      LOC_DATA_REQ  => PIX_DAT_MUX_LOC_DATA_REQ,
      LOC_DATA_ACK  => PIX_DAT_MUX_LOC_DATA_ACK,
      LOC_DATA_SYNC => PIX_DAT_MUX_LOC_DATA_SYNC,
      DATA_OUT      => PIX_DAT_MUX_DATA_OUT,
      DATA_WR       => PIX_DAT_MUX_DATA_WR,
      DATA_SYNC     => PIX_DAT_MUX_DATA_SYNC,
      DATA_BUSY     => PIX_DAT_MUX_DATA_BUSY);

  PIX_DAT_MUX_SEQ_DATA_SYNC            <= syncIn;
  PIX_DAT_MUX_SEQ_DATA_REQ             <= seqDataReq;
  PIX_DAT_MUX_SEQ_DATA_IN  <= dataIn;
  PIX_DAT_MUX_PIX_DATA_REQ             <= PIX_DAT_FIFO_DATA_RDY;
  PIX_DAT_MUX_PIX_DATA_IN(31 downto 0) <= PIX_DAT_FIFO_DATA_OUT(31 downto 0);
  PIX_DAT_MUX_PIX_DATA_SYNC            <= PIX_DAT_FIFO_SYNC_OUT;
  PIX_DAT_MUX_LOC_DATA_SYNC            <= PIX_CMD_DEC_READ_SYNC;
  PIX_DAT_MUX_LOC_DATA_REQ             <= PIX_CMD_DEC_READ_REQ;
  PIX_DAT_MUX_DATA_BUSY                <= SLINK_DATA_BUSY;

  -----------------------------------------------------------------------------
  -- SLINK

  SLinkIfc_1 : SLinkIfc
    port map (
      DATA_IN   => SLINK_DATA_IN,
      DATA_READ => SLINK_DATA_READ,
      DATA_WRT  => SLINK_DATA_WRT,
      LDOWN_N   => SLINK_LDOWN_N,
      LFF_N     => SLINK_LFF_N,
      LRL       => SLINK_LRL,
      RESET_IN  => SLINK_RESET_IN,
      SYNC_IN   => SLINK_SYNC_IN,
      SYSCLK    => SLINK_SYSCLK,
      DATA_BUSY => SLINK_DATA_BUSY,
      DATA_OUT  => SLINK_DATA_OUT,
      DATA_RDY  => SLINK_DATA_RDY,
      RESET_OUT => SLINK_RESET_OUT,
      UCLK      => SLINK_UCLK,
      UCTRL_N   => SLINK_UCTRL_N,
      UD        => SLINK_UD,
      UTEST_N   => SLINK_UTEST_N,
      URESET_N  => SLINK_URESET_N,
      UWEN_N    => SLINK_UWEN_N);

  UCLK                       <= SLINK_UCLK;
  ud(31 downto 0)            <= SLINK_UD(31 downto 0);
  SLINK_LRL(3 downto 0)      <= LRL(3 downto 0);
  SLINK_LFF_N                <= LFF_N;
  UTEST_N                    <= SLINK_UTEST_N;
  SLINK_LDOWN_N              <= LDOWN_N;
  UWEN_N                     <= SLINK_UWEN_N;
  UCTRL_N                    <= SLINK_UCTRL_N;
  URESET_N                   <= SLINK_URESET_N;
  SLINK_DATA_READ            <= dataRead;
  SLINK_RESET_IN             <= RESET;
  SLINK_SYSCLK               <= SYSCLK;
  SLINK_DATA_WRT             <= PIX_DAT_MUX_DATA_WR;
  SLINK_DATA_IN(31 downto 0) <= PIX_DAT_MUX_DATA_OUT(31 downto 0);
  SLINK_SYNC_IN              <= PIX_DAT_MUX_DATA_SYNC;

  dataRdy <= SLINK_DATA_RDY;
  dataOut <= SLINK_DATA_OUT;

  -----------------------------------------------------------------------------
  -- EX dat latch

  ExDataLatchV40_1 : ExDataLatchV40
    port map (
      SYSCLK    => EX_DAT_LATCH_SYSCLK,
      EXDAT_CS  => EX_DAT_LATCH_EXDAT_CS,
      READ      => BIDIR_READ,
      DATA_IN   => EX_DAT_LATCH_DATA_IN,
      DATA_OUT  => BIDIR_DATA_OUT,
      EXDAT_OUT => EX_DAT_LATCH_EXDAT_OUT,
      EXDAT_IN  => EX_DAT_LATCH_EXDAT_IN);

  EX_DAT_LATCH_SYSCLK   <= SYSCLK;
  EX_DAT_LATCH_EXDAT_IN <= EXDAT_IN;
  EXDAT_OUT             <= EX_DAT_LATCH_EXDAT_OUT;
  EX_DAT_LATCH_DATA_IN  <= PIX_CMD_DEC_DATA_OUT(0);
  EX_DAT_LATCH_EXDAT_CS <= PIX_CMD_DEC_SYN_CMD_STB;


  -----------------------------------------------------------------------------
  -- Ser Config Interface
  sda <= 'Z' when SER_CFG_IFC_SDA_ENAB = '0' else
         SER_CFG_IFC_SDA_OUT;
  
  SerConfigIfcV42_1 : SerConfigIfcV42
    port map (
      SYSCLK    => SER_CFG_IFC_SYSCLK,
      RESET     => SER_CFG_IFC_RESET,
      READ      => BIDIR_READ,
      FETCH_CS  => SER_CFG_IFC_FETCH_CS,
      SRCFG_CS  => SER_CFG_IFC_SRCFG_CS,
      WRITE_EN  => SER_CFG_IFC_WRITE_EN,
      DATA_IN   => SER_CFG_IFC_DATA_IN,
      DATA_OUT  => BIDIR_DATA_OUT,
      DATA_ADDR => SER_CFG_IFC_DATA_ADDR,
      SCL       => SER_CFG_IFC_SCL,
      SDA_IN    => SER_CFG_IFC_SDA_IN,
      SDA_OUT   => SER_CFG_IFC_SDA_OUT,
      SDA_ENAB  => SER_CFG_IFC_SDA_ENAB,
      PING      => SER_CFG_IFC_PING,
      PONG      => SER_CFG_IFC_PONG);

  SER_CFG_IFC_RESET                 <= RESET;
  SER_CFG_IFC_SYSCLK                <= SYSCLK;
  SER_CFG_IFC_WRITE_EN              <= vccNet;
  SER_CFG_IFC_SDA_IN                <= sda;
  scl                               <= SER_CFG_IFC_SCL;
  SER_CFG_IFC_DATA_ADDR(6 downto 0) <= PIX_CMD_DEC_ADDRESS(6 downto 0);
  SER_CFG_IFC_DATA_IN(15 downto 0)  <= PIX_CMD_DEC_DATA_OUT(15 downto 0);
  SER_CFG_IFC_SRCFG_CS              <= PIX_CMD_DEC_CFG_CMD_STB;
  SER_CFG_IFC_FETCH_CS              <= PIX_CMD_DEC_FCH_CMD_STB;

  ClkCntrlDecodeV40_1 : ClkCntrlDecodeV40
    port map (
      SYSCLK   => CLK_CTRL_DEC_SYSCLK,
      CLK_CS   => CLK_CTRL_DEC_CLK_CS,
      READ     => BIDIR_READ,
      DATA_IN  => CLK_CTRL_DEC_DATA_IN,
      DATA_OUT => BIDIR_DATA_OUT,
      CLK1D0   => CLK_CTRL_DEC_CLK1D0,
      CLK1D1   => CLK_CTRL_DEC_CLK1D1,
      CLK1D2   => CLK_CTRL_DEC_CLK1D2,
      CLK1D3   => CLK_CTRL_DEC_CLK1D3,
      CLK2D0   => CLK_CTRL_DEC_CLK2D0,
      CLK2D1   => CLK_CTRL_DEC_CLK2D1,
      CLK2D2   => CLK_CTRL_DEC_CLK2D2,
      CLK2D3   => CLK_CTRL_DEC_CLK2D3);

  CLK_CTRL_DEC_SYSCLK              <= SYSCLK;
  CLK_CTRL_DEC_DATA_IN(7 downto 0) <= PIX_CMD_DEC_DATA_OUT(7 downto 0);
  CLK_CTRL_DEC_CLK_CS              <= PIX_CMD_DEC_CLK_CMD_STB;

  -----------------------------------------------------------------------------
  -- Led latch

  LedLatchV40Pix_1 : LedLatchV40Pix
    port map (
      SYSCLK       => LED_LATCH_SYSCLK,
      LED_CS       => LED_LATCH_LED_CS,
      READ         => BIDIR_READ,
      RESET => LED_LATCH_RESET_ACTIVE,
      LED_SRC_1    => LED_LATCH_LED_SRC_1,
      LED_SRC_2    => LED_LATCH_LED_SRC_2,
      LED_SRC_3    => LED_LATCH_LED_SRC_3,
      DATA_IN      => LED_LATCH_DATA_IN,
      DATA_OUT     => BIDIR_DATA_OUT,
      LED_EN       => LED_LATCH_LED_EN);

  led_fib                       <= LED_LATCH_LED_EN;
  LED_LATCH_RESET_ACTIVE        <= RESET;
  LED_LATCH_SYSCLK              <= SYSCLK;
  LED_LATCH_LED_SRC_1           <= PIX_DAT_MUX_DATA_WR;
  LED_LATCH_LED_SRC_2           <= PIX_DAT_MUX_DATA_BUSY;
  LED_LATCH_LED_SRC_3           <= PIX_DAT_FIFO_DATA_RDY;
  LED_LATCH_LED_CS              <= PIX_CMD_DEC_LED_CMD_STB;
  LED_LATCH_DATA_IN(2 downto 0) <= PIX_CMD_DEC_DATA_OUT(2 downto 0);

-----------------------------------------------------------------------------
  -- Clock Control Decode
  BUFT_1 : BUFT
    port map (
      I => CLK_CTRL_DEC_CLK1D1,
      T => CLK_CTRL_DEC_CLK1D0,
      O => clk1f0);
  BUFT_2 : BUFT
    port map (
      I => CLK_CTRL_DEC_CLK1D3,
      T => CLK_CTRL_DEC_CLK1D2,
      O => clk1f1);
  BUFT_3 : BUFT
    port map (
      I => CLK_CTRL_DEC_CLK2D1,
      T => CLK_CTRL_DEC_CLK2D0,
      O => clk2f0);
  BUFT_4 : BUFT
    port map (
      I => CLK_CTRL_DEC_CLK2D3,
      T => CLK_CTRL_DEC_CLK2D2,
      O => clk2f1);



  
end Behavioral;
