------------------------------------------------------------------------
-- Copyright Notice:                                                    
-- (c) Copyright 2004, National Optical Astronomy Observatory, which is 
-- operated for the National Science Foundation by the Association of   
-- Universities for Research in Astronomy under Cooperative Agreement   
-- No. AST-0132798.                                                     
--                                                                      
------------------------------------------------------------------------
-- PROJECT      :   MONSOON
-- BOARD        :   GENERIC
-- DEVICE ID    :   U22 (SEQUENCER FPGA)
-- PARENT MODULE:   SEQUENCER TOP LEVEL (SEQ_FPGA)  
-- MODULE       :   EVENT REGISTER
-- VERSION      :   4.5 
------------------------------------------------------------------------
-- FILE NAME    :   EVENT_REGISTER.VHD
-- AUTHOR       :   PETER MOORE
-- DATE         :   10/28/2005
-- COMPANY      :   NOAO
-- PLATFORM     :   Xilinx ISE 6.2
------------------------------------------------------------------------
-- DESCRIPTION  :   
-- THIS REGISTER DECODES THE SEQUENCER PATTERN AND CONTROL DATA OUTPUTS 
-- TO CATCH ANY MPU WRITES THO TEH SYSTEM GLOBAL EVENT REGISTERS. IT THEN 
-- OUTPUTS THIS EXTERNALLY TO BE OR'ED TO THE PAN EVENTS REGISTER IN THE 
-- PERSONALITY MODULE TO GENERATE A BOARD LEVEL EVENTS SYSTEM COMPATIBLE
-- WITH OTHER PERIPHERAL BOARDS. THE EVENTS (STROBES) ARE USED TO INDICATE
-- CERTAIN GLOBAL EVENTS SUCH AS THE START OF AN EXPOSURE SEQUENCE, START
-- OF FRAME, ETC.
-- 
------------------------------------------------------------------------
-- IMPLEMENTATION NOTES :
-- PATTERN MEMORY BITS AND THEIR FUNCTION
-- BIT
-- 15 START EXPOSURE EVENT
-- 14 
-- 13 
-- 12
-- 11
-- 10
--  9 
--  8 
--  7
--  6
--  5
--  4
--  3 
--  2 
--  1 
--  0 START FRAME EVENT
------------------------------------------------------------------------
-- REVISION HISTORY :
-- DATE         AUTHOR  VERSION  MODIFICATIONS
-- 10/28/2005   PCM     4.5      INITIAL VERSION
------------------------------------------------------------------------
-- PORT DEFINITIONS :


library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
use IEEE.STD_LOGIC_ARITH.ALL;
use IEEE.STD_LOGIC_UNSIGNED.ALL;

entity Event_Register is
    Port ( SYSCLK      : in std_logic;
           reset       : in std_logic;
         MCB_SEL    : in  std_logic;
         SEQ_PAT    : in  std_logic_vector(31 downto 0);
         SEQ_MODE   : in  std_logic_vector(1 downto 0);
         MPU_EVENTS : out std_logic_vector(15 downto 0)
         );
end Event_Register;

architecture Behavioral of Event_Register is

  constant MODE_WRITE16 : std_logic_vector(1 downto 0)  := "10";
  constant EVENT_ADDR   : std_logic_vector(15 downto 0) := x"FFF0";

begin

--    MpuEventRegProc : process(SYSCLK)
--    begin
--        if (rising_edge(SYSCLK)) then
--            MPU_EVENTS <= (others => '0');
--            if (SEQ_MODE = MODE_WRITE16 and MCB_SEL = '1' and SEQ_PAT(31 downto 16) = EVENT_ADDR) then
--                MPU_EVENTS <= SEQ_PAT(15 downto 0);
--            end if;
--        end if;        
--    end process;

  MpuEventRegProc : process(SYSCLK)
  begin
        if rising_edge(SYSCLK) then
            if (reset='1') then
      MPU_EVENTS <= (others => '0');
            elsif (SEQ_MODE = MODE_WRITE16 and MCB_SEL = '1' and SEQ_PAT(31 downto 16) = EVENT_ADDR) then
        MPU_EVENTS <= SEQ_PAT(15 downto 0);
            else
                MPU_EVENTS <= (others => '0');
      end if;
    end if;
  end process;

end Behavioral;
