-- seq_mpu.vhd
-- MCB sequencer, cleaned up 11-Dec-2008 JTO
-- added sync reset to all modules and registers.

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

library unisim;
use unisim.vcomponents.all;

entity seq_mpu is
  port (
           sysclk        : in  std_logic;
    reset          : in    std_logic;
    addr_in        : in    std_logic_vector (15 downto 0);
    data_all_in    : in    std_logic_vector (31 downto 0);
    data_ctl_reg   : in    std_logic_vector (15 downto 0);
    se             : in    std_logic;
    seq_bus_ack    : in    std_logic;
    sync_in        : in    std_logic;
    wr_cmd_reg     : in    std_logic;
    wr_int_reg     : in    std_logic;
    wr_loop_regs   : in    std_logic;
    wr_pat         : in    std_logic;
    wr_prog        : in    std_logic;
    data_cmd_reg   : out   std_logic_vector (15 downto 0);
    data_int_reg   : out   std_logic_vector (31 downto 0);
    data_loop_regs : out   std_logic_vector (15 downto 0);
    data_pat       : out   std_logic_vector (15 downto 0);
    data_prog      : out   std_logic_vector (15 downto 0);
    int_cntr       : out   std_logic_vector (31 downto 0);
    mpu_event      : out   std_logic_vector (15 downto 0);
    seq_bus_req    : out   std_logic;
    seq_ctl        : out   std_logic_vector (31 downto 18);
    seq_pat        : out   std_logic_vector (31 downto 0);
    sta_reg        : out   std_logic_vector (15 downto 0);
    sync_out       : out   std_logic);
end seq_mpu;

architecture seq_mpu_arch of seq_mpu is

  attribute box_type        : string;

  signal addrstackptr       : std_logic_vector (5 downto 0);
  signal addrstkrddata      : std_logic_vector (11 downto 0);
  signal addrstkwrdata      : std_logic_vector (11 downto 0);
  signal addrwrite          : std_logic;
  signal autocancel         : std_logic;
  signal enable_int         : std_logic;
  signal lasreaddata        : std_logic_vector (11 downto 0);
  signal laswritedata       : std_logic_vector (11 downto 0);
  signal lcsptr             : std_logic_vector (5 downto 0);
  signal lcsreaddata        : std_logic_vector (15 downto 0);
  signal lcswritedata       : std_logic_vector (15 downto 0);
  signal localselect        : std_logic;
  signal loopreg0           : std_logic_vector (15 downto 0);
  signal loopreg1           : std_logic_vector (15 downto 0);
  signal loopreg2           : std_logic_vector (15 downto 0);
  signal loopreg3           : std_logic_vector (15 downto 0);
  signal loopreg4           : std_logic_vector (15 downto 0);
  signal loopreg5           : std_logic_vector (15 downto 0);
  signal loopreg6           : std_logic_vector (15 downto 0);
  signal loopreg7           : std_logic_vector (15 downto 0);
  signal loopreg8           : std_logic_vector (15 downto 0);
  signal loopreg9           : std_logic_vector (15 downto 0);
  signal loopreg10          : std_logic_vector (15 downto 0);
  signal loopreg11          : std_logic_vector (15 downto 0);
  signal loopreg12          : std_logic_vector (15 downto 0);
  signal loopreg13          : std_logic_vector (15 downto 0);
  signal loopreg14          : std_logic_vector (15 downto 0);
  signal loopreg15          : std_logic_vector (15 downto 0);
  signal lswrite            : std_logic;
  signal opcodeh            : std_logic_vector (15 downto 0);
  signal patmemptr          : std_logic_vector (10 downto 0);
  signal patrddata          : std_logic_vector (10 downto 0);
  signal patwrdata          : std_logic_vector (10 downto 0);
  signal progptra           : std_logic_vector (9 downto 0);
  signal progptrb           : std_logic_vector (9 downto 0);
  signal seqclk             : std_logic;
  -- signal seqclk0            : std_logic;
  signal se_rst             : std_logic;
  signal sync_efr           : std_logic;
  signal sync_flag          : std_logic;
  signal tc                 : std_logic;
  signal wrt_enables        : std_logic;
  signal data_int_reg_dummy : std_logic_vector (31 downto 0);
  signal seq_bus_req_dummy  : std_logic;
  signal data_cmd_reg_dummy : std_logic_vector (15 downto 0);
  signal seq_ctl_dummy      : std_logic_vector (31 downto 18);
  signal seq_pat_dummy      : std_logic_vector (31 downto 0);
  signal data_prog_dummy    : std_logic_vector (15 downto 0);
  signal int_cntr_dummy     : std_logic_vector (31 downto 0);

  component clock_divide
    port (clkin   : in  std_logic;
           reset  : in  std_logic;
           sync   : in  std_logic;
           ratio  : in  std_logic_vector (1 downto 0);
           clkout : out std_logic);
  end component;

  component command_reg
    port (write        : in  std_logic;
           sysclk      : in  std_logic;
           stnc        : in  std_logic;
           tc          : in  std_logic;
           startexp    : in  std_logic;
           startexprst : in  std_logic;
           reset       : in  std_logic;
           seqrunning  : in  std_logic;
           datain      : in  std_logic_vector (15 downto 0);
           cmdbits     : out std_logic_vector (15 downto 0));
  end component;
  component enables_reg
    port (sysclk        : in  std_logic;
      seqclk       : in  std_logic;
           reset        : in  std_logic;
           seq_running  : in  std_logic;
           wrt_enables  : in  std_logic;
           pattern_data : in  std_logic_vector (31 downto 0);
           enable_int   : out std_logic;
           auto_cancel  : out std_logic;
           rst_startbit : out std_logic;
           sync_out     : out std_logic);
  end component;

  component int_reg
    port (write   : in    std_logic;
           sysclk : in    std_logic;
           reset  : in    std_logic;
           enable : in    std_logic;
           pause  : in    std_logic;
           datain : in    std_logic_vector (31 downto 0);
           tc     : out   std_logic;
           intreg : inout std_logic_vector (31 downto 0);
           intctr : inout std_logic_vector (31 downto 0));
  end component;

--   component loop_addr_stack
--      port ( laswrite     : in    std_logic; 
--             sysclk       : in    std_logic; 
--             lasptr       : in    std_logic_vector (5 downto 0); 
--             laswritedata : in    std_logic_vector (11 downto 0); 
--             lasrddata    : out   std_logic_vector (11 downto 0));
--   end component;
--   
--   component loop_count_stack
--      port ( lcswrite     : in    std_logic; 
--             sysclk       : in    std_logic; 
--             lcsptr       : in    std_logic_vector (5 downto 0); 
--             lcswritedata : in    std_logic_vector (15 downto 0); 
--             lcsrddata    : out   std_logic_vector (15 downto 0));
--   end component;
-- 
--   component pattern_stack
--      port ( patwrite     : in    std_logic; 
--             sysclk       : in    std_logic; 
--             addrptr      : in    std_logic_vector (5 downto 0); 
--             patwritedata : in    std_logic_vector (10 downto 0); 
--             patreaddata  : out   std_logic_vector (10 downto 0));
--   end component;
--
--   component address_stack
--      port ( addrwrite     : in    std_logic; 
--             sysclk        : in    std_logic; 
--             addrptr       : in    std_logic_vector (5 downto 0); 
--             addrwritedata : in    std_logic_vector (11 downto 0); 
--             addrrddata    : out   std_logic_vector (11 downto 0));
--   end component;

-- replace the above "stack" modules with this single parameterized ram:

--  component RAM64S is
--    generic(width : integer := 16);
--    port(wclk : in  std_logic;
--         we   : in  std_logic;
--         a    : in  std_logic_vector(5 downto 0);
--         d    : in  std_logic_vector((width-1) downto 0);
--         o    : out std_logic_vector((width-1) downto 0));
--  end component;
  component genericRam
    port (
      sysClk  : in  std_logic;
      address : in  std_logic_vector;
      wrData  : in  std_logic_vector;
      wr      : in  std_logic;
      rdData  : out std_logic_vector);
  end component;
  
  component loop_registers
    port (sysclk          : in    std_logic;
           reset          : in  std_logic;
           loopregwrite   : in    std_logic;
           loopregaddr    : in    std_logic_vector (3 downto 0);
           loopregdatain  : in    std_logic_vector (15 downto 0);
           loopreg0       : out std_logic_vector (15 downto 0);
           loopreg1       : out std_logic_vector (15 downto 0);
           loopreg2       : out std_logic_vector (15 downto 0);
           loopreg3       : out std_logic_vector (15 downto 0);
           loopreg4       : out std_logic_vector (15 downto 0);
           loopreg5       : out std_logic_vector (15 downto 0);
           loopreg6       : out std_logic_vector (15 downto 0);
           loopreg7       : out std_logic_vector (15 downto 0);
           loopreg8       : out std_logic_vector (15 downto 0);
           loopreg9       : out std_logic_vector (15 downto 0);
           loopreg10      : out std_logic_vector (15 downto 0);
           loopreg11      : out std_logic_vector (15 downto 0);
           loopreg12      : out std_logic_vector (15 downto 0);
           loopreg13      : out std_logic_vector (15 downto 0);
           loopreg14      : out std_logic_vector (15 downto 0);
           loopreg15      : out std_logic_vector (15 downto 0);
           loopregdataout : out   std_logic_vector (15 downto 0));
  end component;

  component pattern_mem
    port (addra  : in  std_logic_vector (11 downto 0);
           dina  : in  std_logic_vector (15 downto 0);
           wea   : in  std_logic;
           clka  : in  std_logic;
           addrb : in  std_logic_vector (10 downto 0);
           clkb  : in  std_logic;
           douta : out std_logic_vector (15 downto 0);
           doutb : out std_logic_vector (31 downto 0));
  end component;

  component progmemcore
    port (addra  : in  std_logic_vector (9 downto 0);
           dina  : in  std_logic_vector (15 downto 0);
           wea   : in  std_logic;
           clka  : in  std_logic;
           addrb : in  std_logic_vector (9 downto 0);
           clkb  : in  std_logic;
           douta : out std_logic_vector (15 downto 0);
           doutb : out std_logic_vector (15 downto 0));
  end component;

  component synclogic
    port (sysclk        : in  std_logic;
           reset        : in  std_logic;
           sync_efr     : in  std_logic;
           ext_sync_in  : in  std_logic;
           ext_sync_out : out std_logic;
           sync_flag    : out std_logic;
           data_ctl_reg : in  std_logic_vector (15 downto 0));
  end component;

--   component bufg
--      port ( i : in    std_logic; 
--             o : out   std_logic);
--   end component;
--   attribute box_type of bufg : component is "black_box";

  component event_register
    port (sysclk      : in  std_logic;
           reset      : in  std_logic;
           mcb_sel    : in  std_logic;
           seq_pat    : in  std_logic_vector (31 downto 0);
           seq_mode   : in  std_logic_vector (1 downto 0);
           mpu_events : out std_logic_vector (15 downto 0));
  end component;

  component decodeexecute
    port (sysclk              : in    std_logic;
           seqclk             : in  std_logic;
           reset              : in  std_logic;
           seqrunflag         : in  std_logic;
           autocancelflag     : in  std_logic;
           seqbusack          : in  std_logic;
           cmdreg             : in  std_logic_vector (15 downto 0);
           opcodel            : in  std_logic_vector (15 downto 0);
           opcodeh            : in  std_logic_vector (15 downto 0);
           loopreg0           : in  std_logic_vector (15 downto 0);
           loopreg1           : in  std_logic_vector (15 downto 0);
           loopreg2           : in  std_logic_vector (15 downto 0);
           loopreg3           : in  std_logic_vector (15 downto 0);
           loopreg4           : in  std_logic_vector (15 downto 0);
           loopreg5           : in  std_logic_vector (15 downto 0);
           loopreg6           : in  std_logic_vector (15 downto 0);
           loopreg7           : in  std_logic_vector (15 downto 0);
           loopreg8           : in  std_logic_vector (15 downto 0);
           loopreg9           : in  std_logic_vector (15 downto 0);
           loopreg10          : in  std_logic_vector (15 downto 0);
           loopreg11          : in  std_logic_vector (15 downto 0);
           loopreg12          : in  std_logic_vector (15 downto 0);
           loopreg13          : in  std_logic_vector (15 downto 0);
           loopreg14          : in  std_logic_vector (15 downto 0);
           loopreg15          : in  std_logic_vector (15 downto 0);
           patterndata        : in  std_logic_vector (15 downto 0);
           panaddr            : in  std_logic_vector (15 downto 0);
           patstackreaddata   : in  std_logic_vector (10 downto 0);
           lasreaddata        : in  std_logic_vector (11 downto 0);
           lcsreaddata        : in  std_logic_vector (15 downto 0);
           addrstackreaddata  : in  std_logic_vector (11 downto 0);
           seqbusreq          : out std_logic;
           patmemptr          : out std_logic_vector (10 downto 0);
           lsptr              : out std_logic_vector (5 downto 0);
           addrstackptr       : out std_logic_vector (5 downto 0);
           seqenableswrite    : out std_logic;
           lswrite            : out std_logic;
           addrstackwrite     : out std_logic;
           progptra           : out std_logic_vector (9 downto 0);
           progptrb           : out std_logic_vector (9 downto 0);
           patstackwritedata  : out std_logic_vector (10 downto 0);
           seqcontrol         : out std_logic_vector (31 downto 18);
           laswritedata       : out std_logic_vector (11 downto 0);
           lcswritedata       : out std_logic_vector (15 downto 0);
           addrstackwritedata : out std_logic_vector (11 downto 0);
           statusreg          : out std_logic_vector (15 downto 0);
           localsel           : out std_logic);
  end component;
  
begin

  data_cmd_reg(15 downto 0) <= data_cmd_reg_dummy(15 downto 0);
  data_int_reg(31 downto 0) <= data_int_reg_dummy(31 downto 0);
  data_prog(15 downto 0)    <= data_prog_dummy(15 downto 0);
  int_cntr(31 downto 0)     <= int_cntr_dummy(31 downto 0);
  seq_bus_req               <= seq_bus_req_dummy;
  seq_ctl(31 downto 18)     <= seq_ctl_dummy(31 downto 18);
  seq_pat(31 downto 0)      <= seq_pat_dummy(31 downto 0);

--   mpucalladdrstack : address_stack
--      port map (addrptr(5 downto 0)=>addrstackptr(5 downto 0),
--                addrwrite=>addrwrite,
--                addrwritedata(11 downto 0)=>addrstkwrdata(11 downto 0),
--                sysclk=>sysclk,
--                addrrddata(11 downto 0)=>addrstkrddata(11 downto 0));

--  mpucalladdrstack : RAM64S
--    generic map(width => 12)
--    port map(
--      wclk => sysclk,
--      we   => addrwrite,
--      a    => addrstackptr(5 downto 0),
--      d    => addrstkwrdata(11 downto 0),
--      o    => addrstkrddata(11 downto 0)
--      );

  mpucalladdrstack: genericRam
    port map (
      sysClk  => sysClk,
      address => addrstackptr(5 downto 0),
      wrData  => addrstkwrdata(11 downto 0),
      wr      => addrwrite,
      rdData  => addrstkrddata(11 downto 0));
  
  mpuclockdivider : clock_divide
    port map (clkin             => sysclk,
              reset             => reset,
              ratio(1 downto 0) => data_ctl_reg(3 downto 2),
              sync              => sync_flag,
              clkout            => seqclk);

  mpucommandreg : command_reg
    port map (datain(15 downto 0)  => data_all_in(15 downto 0),
              reset                => reset,
              seqrunning           => data_ctl_reg(0),
              startexp             => se,
              startexprst          => se_rst,
              stnc                 => sync_flag,
              sysclk               => sysclk,
              tc                   => tc,
              write                => wr_cmd_reg,
              cmdbits(15 downto 0) => data_cmd_reg_dummy(15 downto 0));

  mpuenableregister : enables_reg
    port map (sysclk                    => sysclk, seqclk => seqclk, reset => reset,
              pattern_data(31 downto 0) => seq_pat_dummy(31 downto 0),
              seq_running               => data_ctl_reg(0),
              wrt_enables               => wrt_enables,
              auto_cancel               => autocancel,
              enable_int                => enable_int,
              rst_startbit              => se_rst,
              sync_out                  => sync_efr);

  mpuintegrationreg : int_reg
    port map (datain(31 downto 0) => data_all_in(31 downto 0),
              enable              => enable_int,
              pause               => data_ctl_reg(1),
              reset               => reset,
              sysclk              => sysclk,
              write               => wr_int_reg,
              intctr(31 downto 0) => int_cntr_dummy(31 downto 0),
              intreg(31 downto 0) => data_int_reg_dummy(31 downto 0),
              tc                  => tc);

--   mpuloopaddrstack : loop_addr_stack
--      port map (lasptr(5 downto 0)=>lcsptr(5 downto 0),
--                laswrite=>lswrite,
--                laswritedata(11 downto 0)=>laswritedata(11 downto 0),
--                sysclk=>sysclk,
--                lasrddata(11 downto 0)=>lasreaddata(11 downto 0));
  
--  mpuloopaddrstack : RAM64S
--    generic map(width => 12)
--    port map(
--      wclk => sysclk,
--      we   => lswrite,
--      a    => lcsptr(5 downto 0),
--      d    => laswritedata(11 downto 0),
--      o    => lasreaddata(11 downto 0)
--      );
  mpuloopaddrstack: genericRam
    port map (
      sysClk  => sysClk,
      address => lcsptr(5 downto 0),
      wrData  => laswritedata(11 downto 0),
      wr      => lswrite,
      rdData  => lasreaddata(11 downto 0));
  
--   mpuloopcntrstack : loop_count_stack
--      port map (lcsptr(5 downto 0)=>lcsptr(5 downto 0),
--                lcswrite=>lswrite,
--                lcswritedata(15 downto 0)=>lcswritedata(15 downto 0),
--                sysclk=>sysclk,
--                lcsrddata(15 downto 0)=>lcsreaddata(15 downto 0));

--  mpuloopcntrstack : RAM64S
--    generic map(width => 16)
--    port map(
--      wclk => sysclk,
--      we   => lswrite,
--      a    => lcsptr(5 downto 0),
--      d    => lcswritedata(15 downto 0),
--      o    => lcsreaddata(15 downto 0)
--      );
  mpuloopcntrstack: genericRam
    port map (
      sysClk  => sysClk,
      address => lcsptr(5 downto 0),
      wrData  => lcswritedata(15 downto 0),
      wr      => lswrite,
      rdData  => lcsreaddata(15 downto 0));
  
  mpuloopregs : loop_registers
    port map (loopregaddr(3 downto 0)     => addr_in(3 downto 0),
              loopregdatain(15 downto 0)  => data_all_in(15 downto 0),
              loopregwrite                => wr_loop_regs,
              sysclk                      => sysclk, reset => reset,
              loopregdataout(15 downto 0) => data_loop_regs(15 downto 0),
              loopreg0(15 downto 0)       => loopreg0(15 downto 0),
              loopreg1(15 downto 0)       => loopreg1(15 downto 0),
              loopreg2(15 downto 0)       => loopreg2(15 downto 0),
              loopreg3(15 downto 0)       => loopreg3(15 downto 0),
              loopreg4(15 downto 0)       => loopreg4(15 downto 0),
              loopreg5(15 downto 0)       => loopreg5(15 downto 0),
              loopreg6(15 downto 0)       => loopreg6(15 downto 0),
              loopreg7(15 downto 0)       => loopreg7(15 downto 0),
              loopreg8(15 downto 0)       => loopreg8(15 downto 0),
              loopreg9(15 downto 0)       => loopreg9(15 downto 0),
              loopreg10(15 downto 0)      => loopreg10(15 downto 0),
              loopreg11(15 downto 0)      => loopreg11(15 downto 0),
              loopreg12(15 downto 0)      => loopreg12(15 downto 0),
              loopreg13(15 downto 0)      => loopreg13(15 downto 0),
              loopreg14(15 downto 0)      => loopreg14(15 downto 0),
              loopreg15(15 downto 0)      => loopreg15(15 downto 0));

  mpupatternmemory : pattern_mem
    port map (addra(11 downto 0) => addr_in(11 downto 0),
              addrb(10 downto 0) => patmemptr(10 downto 0),
              clka               => sysclk,
              clkb               => sysclk,
              dina(15 downto 0)  => data_all_in(15 downto 0),
              wea                => wr_pat,
              douta(15 downto 0) => data_pat(15 downto 0),
              doutb(31 downto 0) => seq_pat_dummy(31 downto 0));

--   mpupatternptrstack : pattern_stack
--      port map (addrptr(5 downto 0)=>addrstackptr(5 downto 0),
--                patwrite=>addrwrite,
--                patwritedata(10 downto 0)=>patwrdata(10 downto 0),
--                sysclk=>sysclk,
--                patreaddata(10 downto 0)=>patrddata(10 downto 0));

--  mpupatternptrstack : RAM64S
--    generic map(width => 11)
--    port map(
--      wclk => sysclk,
--      we   => addrwrite,
--      a    => addrstackptr(5 downto 0),
--      d    => patwrdata(10 downto 0),
--      o    => patrddata(10 downto 0)
--      );
  mpupatternptrstack: genericRam
    port map (
      sysClk  => sysClk,
      address => addrstackptr(5 downto 0),
      wrData  => patwrdata(10 downto 0),
      wr      => addrwrite,
      rdData  => patrddata(10 downto 0));
  
  mpuprogrammemory : progmemcore
    port map (addra(9 downto 0)  => progptra(9 downto 0),
              addrb(9 downto 0)  => progptrb(9 downto 0),
              clka               => sysclk,
              clkb               => sysclk,
              dina(15 downto 0)  => data_all_in(15 downto 0),
              wea                => wr_prog,
              douta(15 downto 0) => data_prog_dummy(15 downto 0),
              doutb(15 downto 0) => opcodeh(15 downto 0));

  mpusynclogic : synclogic
    port map (data_ctl_reg(15 downto 0) => data_ctl_reg(15 downto 0),
              ext_sync_in               => sync_in,
              sync_efr                  => sync_efr,
              sysclk                    => sysclk, reset => reset,
              ext_sync_out              => sync_out,
              sync_flag                 => sync_flag);

  event_reg : event_register
    port map (
      sysclk       => sysclk,
      reset                   => reset,
      mcb_sel                 => localselect,
      seq_mode(1 downto 0)    => seq_ctl_dummy(31 downto 30),
      seq_pat(31 downto 0)    => seq_pat_dummy(31 downto 0),
      mpu_events(15 downto 0) => mpu_event(15 downto 0)
      );

  decode_inst : decodeexecute
    port map (
      sysclk                          => sysclk,
      addrstackreaddata(11 downto 0)  => addrstkrddata(11 downto 0),
      autocancelflag                  => autocancel,
      cmdreg(15 downto 0)             => data_cmd_reg_dummy(15 downto 0),
      lasreaddata(11 downto 0)        => lasreaddata(11 downto 0),
      lcsreaddata(15 downto 0)        => lcsreaddata(15 downto 0),
      loopreg0(15 downto 0)           => loopreg0(15 downto 0),
      loopreg1(15 downto 0)           => loopreg1(15 downto 0),
      loopreg2(15 downto 0)           => loopreg2(15 downto 0),
      loopreg3(15 downto 0)           => loopreg3(15 downto 0),
      loopreg4(15 downto 0)           => loopreg4(15 downto 0),
      loopreg5(15 downto 0)           => loopreg5(15 downto 0),
      loopreg6(15 downto 0)           => loopreg6(15 downto 0),
      loopreg7(15 downto 0)           => loopreg7(15 downto 0),
      loopreg8(15 downto 0)           => loopreg8(15 downto 0),
      loopreg9(15 downto 0)           => loopreg9(15 downto 0),
      loopreg10(15 downto 0)          => loopreg10(15 downto 0),
      loopreg11(15 downto 0)          => loopreg11(15 downto 0),
      loopreg12(15 downto 0)          => loopreg12(15 downto 0),
      loopreg13(15 downto 0)          => loopreg13(15 downto 0),
      loopreg14(15 downto 0)          => loopreg14(15 downto 0),
      loopreg15(15 downto 0)          => loopreg15(15 downto 0),
      opcodeh(15 downto 0)            => opcodeh(15 downto 0),
      opcodel(15 downto 0)            => data_prog_dummy(15 downto 0),
      panaddr(15 downto 0)            => addr_in(15 downto 0),
      patstackreaddata(10 downto 0)   => patrddata(10 downto 0),
      patterndata(15 downto 0)        => seq_pat_dummy(15 downto 0),
      reset                           => reset,
      seqbusack                       => seq_bus_ack,
      seqclk                          => seqclk,
      seqrunflag                      => data_ctl_reg(0),
      addrstackwrite                  => addrwrite,
      addrstackwritedata(11 downto 0) => addrstkwrdata(11 downto 0),
      laswritedata(11 downto 0)       => laswritedata(11 downto 0),
      lcswritedata(15 downto 0)       => lcswritedata(15 downto 0),
      lswrite                         => lswrite,
      patstackwritedata(10 downto 0)  => patwrdata(10 downto 0),
      progptra(9 downto 0)            => progptra(9 downto 0),
      progptrb(9 downto 0)            => progptrb(9 downto 0),
      seqcontrol(31 downto 18)        => seq_ctl_dummy(31 downto 18),
      seqenableswrite                 => wrt_enables,
      statusreg(15 downto 0)          => sta_reg(15 downto 0),
      addrstackptr(5 downto 0)        => addrstackptr(5 downto 0),
      localsel                        => localselect,
      lsptr(5 downto 0)               => lcsptr(5 downto 0),
      patmemptr(10 downto 0)          => patmemptr(10 downto 0),
      seqbusreq                       => seq_bus_req_dummy);

end seq_mpu_arch;


