library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;
-- synopsys translate_off
library UNISIM;
use UNISIM.Vcomponents.all;
-- synopsys translate_on

entity topSeqFpga is
  port (
    reset          : in    std_logic;
    SYNC_IN        : in    std_logic;
    SYSCLK         : in    std_logic;
    TEMP_DOUT      : in    std_logic;
    BRD_SLCT_N     : out   std_logic_vector (8 downto 2);
    CLK2           : out   std_logic;
    CLK3           : out   std_logic;
    CLK4           : out   std_logic;
    CLK5           : out   std_logic;
    CLK6           : out   std_logic;
    CLK7           : out   std_logic;
    CLK8           : out   std_logic;
    DEV_ADDR       : out   std_logic_vector (4 downto 0);
    FPGA_CTL_1     : out   std_logic;
    FPGA_CTL_2     : out   std_logic;
    FPGA_CTL_6     : out   std_logic;
    LED_SEQ        : out   std_logic;
    PROGRAM_N      : out   std_logic;
    RA_LINK_N      : out   std_logic;
    SEQ_DATA       : out   std_logic_vector (31 downto 0);
    SEQ_MODE       : out   std_logic_vector (1 downto 0);
    START_EXP      : out   std_logic;
    SYNC_OUT       : out   std_logic;
    TEMP_DIN       : out   std_logic;
    TEMP_SCLK      : out   std_logic;
    DQ             : inout std_logic;

    -- Sync Delay chip Interface
    delChipClk : out std_logic;
    delChipD   : out std_logic;
    delChipE   : out std_logic;

    -- Fpga interface
    dataRdy : in std_logic;
    dataIn : in std_logic_vector(31 downto 0);
    dataRead : out std_logic;
    dataOut : out std_logic_vector(31 downto 0);
    cmdRdy : out std_logic;
    seqDataReq : out std_logic;
    syncOut : out std_logic

    

    );

end topSeqFpga;

architecture BEHAVIORAL of topSeqFpga is
  attribute BOX_TYPE            : string;
  attribute BUFR_DIVIDE         : string;
  attribute IOSTANDARD          : string;
  attribute CAPACITANCE         : string;
  attribute SLEW                : string;
  attribute DRIVE               : string;
  signal ASYNC_FLAG             : std_logic;
  signal BRDSEL                 : std_logic_vector (7 downto 0);
  signal CLKEN_SEL              : std_logic;
  signal CTL_BUSS               : std_logic_vector (15 downto 0);
  signal DHE_SYNC_IN            : std_logic;
  signal ECHO_REQ               : std_logic;
  signal locaddr                : std_logic_vector (15 downto 0);
  signal LOCAL_CMD              : std_logic;
  signal LOCAL_SEL              : std_logic;
--  signal LOCAL_SYNC             : std_logic;
  signal LOCDATA                : std_logic_vector (31 downto 0);
  signal MPU_BUS_ACK            : std_logic;
  signal MPU_BUS_REQ            : std_logic;
  signal PIX_WRT_N              : std_logic;
  signal READ_DECODE            : std_logic;
  signal READ_STROBE            : std_logic;
  signal SEQ_ADDRDATA           : std_logic_vector (31 downto 0);
  signal SEQ_BUS_ACK            : std_logic;
  signal SEQ_BUS_REQ            : std_logic;
  signal SEQ_CTL                : std_logic_vector (31 downto 18);
  signal SEQ_DEVADDR            : std_logic_vector (4 downto 0);
  signal SEQ_MODE_SEL           : std_logic_vector (1 downto 0);
  signal SN_DATA                : std_logic_vector (47 downto 0);
--  signal SOFT_RESET             : std_logic;
  signal SYNC_OKAY              : std_logic;
  signal TST_CNTR_DATA          : std_logic_vector (31 downto 0);
  signal TST_CNTR_REQ           : std_logic;
  signal TST_CNTR_WRT           : std_logic;
  signal WRITE_DECODE           : std_logic;
  signal WRITE_STROBE           : std_logic;
  signal WRT_PGM_MEMORY         : std_logic;
  signal WR_LOOPREGS            : std_logic;
  signal XLXN_9                 : std_logic;
  signal XLXN_10                : std_logic_vector (15 downto 0);
  signal XLXN_11                : std_logic;
  signal XLXN_12                : std_logic_vector (31 downto 0);
  signal XLXN_14                : std_logic_vector (15 downto 0);
  signal XLXN_15                : std_logic;
  signal XLXN_16                : std_logic_vector (15 downto 0);
  signal XLXN_18                : std_logic_vector (15 downto 0);
  signal XLXN_19                : std_logic_vector (15 downto 0);
  signal XLXN_43                : std_logic_vector (31 downto 0);
  signal XLXN_70                : std_logic_vector (15 downto 0);
  signal hardReset               : std_logic;
  signal hardReset_n : std_logic;
  signal XLXN_214               : std_logic_vector (31 downto 0);
  signal XLXN_298               : std_logic_vector (31 downto 0);
--  signal XLXN_313               : std_logic;
--  signal XLXN_330               : std_logic_vector (31 downto 0);
  signal XLXN_438               : std_logic;
  signal XLXN_439               : std_logic_vector (2 downto 0);
  signal XLXN_450               : std_logic;
  signal XLXN_464               : std_logic;
  signal XLXN_465               : std_logic_vector (9 downto 0);
  signal XLXN_466               : std_logic_vector (15 downto 0);
  signal START_EXP_DUMMY        : std_logic;
  signal SYNC_OUT_DUMMY         : std_logic;
  signal FPGA_CTL_1_DUMMY       : std_logic;


  signal syncDelayWrite : std_logic;
  signal syncDelayReg : std_logic_vector(7 downto 0);

  component ClockEnableRegister
    port (CLK          : in  std_logic;
          RST          : in  std_logic;
          WRT          : in  std_logic;
          CLK_EN_DATA  : in  std_logic_vector (15 downto 0);
          clk2         : out std_logic;
          clk3         : out std_logic;
          clk4         : out std_logic;
          clk5         : out std_logic;
          CLK6         : out std_logic;
          CLK7         : out std_logic;
          CLK8         : out std_logic;
          CLK_DATA_OUT : out std_logic_vector (15 downto 0));
  end component;


  component LedLatchV40Seq
    port (sysclk       : in    std_logic;
          reset_active : in    std_logic;
          led_src_1    : in    std_logic;
          led_src_2    : in    std_logic;
          led_src_3    : in    std_logic;
          data_in      : in    std_logic_vector (2 downto 0);
          data_out     : inout std_logic_vector (2 downto 0);
          led_en       : out   std_logic;
          wrt          : in    std_logic);
  end component;

  component seq_mpu
    port (
      sysclk         : in  std_logic;
      reset          : in  std_logic;
      addr_in        : in  std_logic_vector (15 downto 0);
      data_all_in    : in  std_logic_vector (31 downto 0);
      data_ctl_reg   : in  std_logic_vector (15 downto 0);
      se             : in  std_logic;
      seq_bus_ack    : in  std_logic;
      sync_in        : in  std_logic;
      wr_cmd_reg     : in  std_logic;
      wr_int_reg     : in  std_logic;
      wr_loop_regs   : in  std_logic;
      wr_pat         : in  std_logic;
      wr_prog        : in  std_logic;
      data_cmd_reg   : out std_logic_vector (15 downto 0);
      data_int_reg   : out std_logic_vector (31 downto 0);
      data_loop_regs : out std_logic_vector (15 downto 0);
      data_pat       : out std_logic_vector (15 downto 0);
      data_prog      : out std_logic_vector (15 downto 0);
      int_cntr       : out std_logic_vector (31 downto 0);
      mpu_event      : out std_logic_vector (15 downto 0);
      seq_bus_req    : out std_logic;
      seq_ctl        : out std_logic_vector (31 downto 18);
      seq_pat        : out std_logic_vector (31 downto 0);
      sta_reg        : out std_logic_vector (15 downto 0);
      sync_out       : out std_logic);
  end component;

  component Pan_Command_Decode
    port (CLK           : in    std_logic;
          reset         : in    std_logic;
          DATA_IN_VALID : in    std_logic;
          SEQ_BUS_ACK   : in    std_logic;
          async_pending : in    std_logic;
          DATA_IN       : in    std_logic_vector (31 downto 0);
          DATA_IN_RD    : out std_logic;
          MODE          : inout std_logic_vector (1 downto 0);
          DEVADDR       : inout std_logic_vector (4 downto 0);
          ADDRDATA      : inout std_logic_vector (31 downto 0);
          BOARD_SELECT  : inout std_logic_vector (7 downto 0);
          LOCSEL        : out   std_logic;
          SEQ_BUS_REQ   : out   std_logic;
          pixfifo_wrt_n : out   std_logic;
          START_EXP     : out   std_logic;
          echo_req      : out   std_logic;
          WRT           : out   std_logic;
          rd            : out   std_logic;
          WRT_PROG      : out   std_logic;
          sync_flag     : out   std_logic;
          HARD_RST      : out   std_logic;
          SOFT_RST      : out   std_logic;
          echo_data     : out   std_logic_vector (31 downto 0);
          LOCDATA       : out   std_logic_vector (31 downto 0);
          LOCADDR       : out   std_logic_vector (15 downto 0));
  end component;

  component PATTERN_GENERATOR
    port (CLK      : in  std_logic;
          RST      : in  std_logic;
          LOAD     : in  std_logic;
          DATA_IN  : in  std_logic_vector (31 downto 0);
          DATA_RDY : out std_logic;
          DATA_OUT : out std_logic_vector (31 downto 0);
          strt_exp : in  std_logic;
          enable   : in  std_logic);
  end component;

  component Personality_ModuleV45
    port (
      SYSCLK       : in  std_logic;
      reset        : in  std_logic;
      WRITE        : in  std_logic;
      BOARD_SEL    : in  std_logic;
      LED_REG_SEL  : out std_logic;
      LED_DATA     : in  std_logic_vector(2 downto 0);
      TEMP_DATA_IN : in  std_logic_vector(9 downto 0);
      SN_DATA      : in  std_logic_vector(47 downto 0);
      ADDRESS      : in  std_logic_vector(15 downto 0);
      STATUS_REG   : in  std_logic_vector(15 downto 0);
      CLOCKEN_REG  : in  std_logic_vector(15 downto 0);
      SYNCDEL_REG  : in  std_logic_vector(7 downto 0);
      TST_CTR_REG  : in  std_logic_vector(31 downto 0);
      SEQ_CMD_REG  : in  std_logic_vector(15 downto 0);
      SEQ_INT_REG  : in  std_logic_vector(31 downto 0);
      SEQ_INT_CTR  : in  std_logic_vector(31 downto 0);
      SEQ_LPP_REG  : in  std_logic_vector(15 downto 0);
      SEQ_PAT_MEM  : in  std_logic_vector(15 downto 0);
      SEQ_PGM_MEM  : in  std_logic_vector(15 downto 0);
      ECHO_DATA_IN : in  std_logic_vector(31 downto 0);
      DATA_IN      : in  std_logic_vector(15 downto 0);
      DATA_OUT     : out std_logic_vector(31 downto 0);
      CONTROL_OUT  : out std_logic_vector(15 downto 0);
      WRITE_STB    : out std_logic;
      CLOCKEN_SEL  : out std_logic;
      SYNCDEL_SEL  : out std_logic;
      program_n    : out std_logic;
      SEQ_CMD_SEL  : out std_logic;
      SEQ_INT_SEL  : out std_logic;
      SEQ_LPP_SEL  : out std_logic;
      SEQ_PAT_SEL  : out std_logic;
      TST_CTR_REQ  : in  std_logic;
      TST_CTR_WRT  : out std_logic;
      TST_CTR_ENB  : out std_logic;
      TEMP_RD_STB  : out std_logic;
      SYNC_OUT     : out std_logic;
      READ         : in  std_logic;
      READ_STROBE  : in  std_logic;
      ECHO_REQ     : in  std_logic;
      CMD_OUT      : out std_logic;
--      EXPOSE_START : out std_logic;
--      FRAME_START  : out std_logic;
      MPU_EVENTS   : in  std_logic_vector(15 downto 0));
  end component;
  
  component syncDelay
    port (
      sysclk      : in  std_logic;
      reset       : in  std_logic;
      write       : in  std_logic;
      delayDatIn  : in  std_logic_vector(7 downto 0);
      delayDatOut : out std_logic_vector(7 downto 0);
      delChipClk  : out std_logic;
      delChipD    : out std_logic;
      delChipE    : out std_logic);
  end component;

  component resetSync
    port (
      reset     : in  std_logic;
      sysClk    : in  std_logic;
      syncRcvd  : in  std_logic;
      asyncFlag : out std_logic);
  end component;


  component Sequencer_Bus_Mux
    port (CLK               : in  std_logic;
          RST               : in  std_logic;
          SEQ_BUS_REQ       : in  std_logic;
          DHE_BUS_REQ       : in  std_logic;
          SEQ_ADDRDATA_IN   : in  std_logic_vector (31 downto 0);
          SEQ_DEV_ADDR_IN   : in  std_logic_vector (4 downto 0);
          SEQ_MODE_IN       : in  std_logic_vector (1 downto 0);
          SEQ_BOARD_SEL_IN  : in  std_logic_vector (6 downto 0);
          DHE_ADDRDATA_IN   : in  std_logic_vector (31 downto 0);
          DHE_DEV_ADDR_IN   : in  std_logic_vector (4 downto 0);
          DHE_MODE_IN       : in  std_logic_vector (1 downto 0);
          DHE_BOARD_SEL_IN  : in  std_logic_vector (7 downto 0);
          SEQ_BUS_ACK       : out std_logic;
          DHE_BUS_ACK       : out std_logic;
          BUS_ADDRDATA_OUT  : out std_logic_vector (31 downto 0);
          BUS_DEV_ADDR_OUT  : out std_logic_vector (4 downto 0);
          BUS_MODE_OUT      : out std_logic_vector (1 downto 0);
          BUS_BOARD_SEL_OUT : out std_logic_vector (8 downto 2));
  end component;

  component serno_interface
    port (
      clock     : in    std_logic;      -- 40MHz system clock
      reset     : in    std_logic;      -- active HIGH reset
      sn_data   : out   std_logic_vector (47 downto 0);
      sn_crc_ok : out   std_logic;
      sn_io     : inout std_logic
      );
  end component;

  component TempSensor
    port (sysclk    : in  std_logic;
          read_temp : in  std_logic;
          temp_dout : in  std_logic;
          temp_din  : out std_logic;
          temp_sclk : out std_logic;
          temp_data : out std_logic_vector (9 downto 0));
  end component;

  component BUFG
    port (I : in  std_logic;
          O : out std_logic);
  end component;
  attribute BOX_TYPE of BUFG : component is "BLACK_BOX";

  component BUF
    port (I : in  std_logic;
          O : out std_logic);
  end component;

  attribute BOX_TYPE of BUF : component is "BLACK_BOX";

  component BUFR
    -- synopsys translate_off
    generic(BUFR_DIVIDE : string := "BYPASS");
    -- synopsys translate_on
    port (I   : in  std_logic;
          CLR : in  std_logic;
          CE  : in  std_logic;
          O   : out std_logic);
  end component;
  attribute BUFR_DIVIDE of BUFR : component is "BYPASS";
  attribute BOX_TYPE of BUFR    : component is "BLACK_BOX";

  component OBUFT
    port (I : in  std_logic;
          T : in  std_logic;
          O : out std_logic);
  end component;
  attribute IOSTANDARD of OBUFT  : component is "DEFAULT";
  attribute CAPACITANCE of OBUFT : component is "DONT_CARE";
  attribute SLEW of OBUFT        : component is "SLOW";
  attribute DRIVE of OBUFT       : component is "12";
  attribute BOX_TYPE of OBUFT    : component is "BLACK_BOX";
  
begin
  FPGA_CTL_1 <= FPGA_CTL_1_DUMMY;
  START_EXP  <= START_EXP_DUMMY;
  SYNC_OUT   <= SYNC_OUT_DUMMY;
  CLKENABLE : ClockEnableRegister
    port map (CLK                       => SYSCLK,
              CLK_EN_DATA(15 downto 0)  => LOCDATA(15 downto 0),
              RST                       => RESET,
              WRT                       => CLKEN_SEL,
              CLK_DATA_OUT(15 downto 0) => XLXN_70(15 downto 0),
              clk2                      => CLK2,
              clk3                      => CLK3,
              clk4                      => CLK4,
              clk5                      => CLK5,
              CLK6                      => CLK6,
              CLK7                      => CLK7,
              CLK8                      => CLK8);


  LEDCONTROL : LedLatchV40Seq
    port map (data_in(2 downto 0)  => LOCDATA(2 downto 0),
              led_src_1            => dataRdy,
              led_src_2            => SEQ_BUS_REQ,
              led_src_3            => MPU_BUS_REQ,
              reset_active         => ASYNC_FLAG,
              sysclk               => SYSCLK,
              wrt                  => XLXN_438,
              led_en               => LED_SEQ,
              data_out(2 downto 0) => XLXN_439(2 downto 0));

  seq_mpu_1: seq_mpu
    port map (
      sysclk         => sysclk,
      reset          => reset,
      addr_in        => locaddr(15 downto 0),
      data_all_in    => LOCDATA(31 downto 0),
      data_ctl_reg   => CTL_BUSS(15 downto 0),
      se             => START_EXP_DUMMY,
      seq_bus_ack    => MPU_BUS_ACK,
      sync_in        => DHE_SYNC_IN,
      wr_cmd_reg     => XLXN_9,
      wr_int_reg     => XLXN_11,
      wr_loop_regs   => WR_LOOPREGS,
      wr_pat         => XLXN_15,
      wr_prog        => WRT_PGM_MEMORY,
      data_cmd_reg   => XLXN_10(15 downto 0),
      data_int_reg   => XLXN_12(31 downto 0),
      data_loop_regs => XLXN_14(15 downto 0),
      data_pat       => XLXN_16(15 downto 0),
      data_prog      => XLXN_18(15 downto 0),
      int_cntr       => XLXN_214(31 downto 0),
      mpu_event      => XLXN_466(15 downto 0),
      seq_bus_req    => MPU_BUS_REQ,
      seq_ctl(31 downto 18) => SEQ_CTL(31 downto 18),
      seq_pat        => XLXN_43(31 downto 0),
      sta_reg        => XLXN_19(15 downto 0),
      sync_out       => SYNC_OUT_DUMMY);

  PANCOMMANDDEC : Pan_Command_Decode
    port map (async_pending            => ASYNC_FLAG,
              CLK                      => SYSCLK,
              DATA_IN(31 downto 0)     => dataIn,
              DATA_IN_VALID            => dataRdy,
              reset                    => RESET,
              SEQ_BUS_ACK              => SEQ_BUS_ACK,
              echo_data(31 downto 0)   => XLXN_298(31 downto 0),
              echo_req                 => ECHO_REQ,
              HARD_RST                 => hardReset,
              LOCADDR(15 downto 0)     => locaddr(15 downto 0),
              LOCDATA(31 downto 0)     => LOCDATA(31 downto 0),
              LOCSEL                   => LOCAL_SEL,
              pixfifo_wrt_n            => PIX_WRT_N,
              rd                       => READ_DECODE,
              SEQ_BUS_REQ              => SEQ_BUS_REQ,
--              SOFT_RST                 => SOFT_RESET,
              START_EXP                => START_EXP_DUMMY,
              sync_flag                => SYNC_OKAY,
              WRT                      => WRITE_DECODE,
              WRT_PROG                 => WRT_PGM_MEMORY,
              ADDRDATA(31 downto 0)    => SEQ_ADDRDATA(31 downto 0),
              BOARD_SELECT(7 downto 0) => BRDSEL(7 downto 0),
              DATA_IN_RD               => dataRead,
              DEVADDR(4 downto 0)      => SEQ_DEVADDR(4 downto 0),
              MODE(1 downto 0)         => SEQ_MODE_SEL(1 downto 0));

  hardReset_n <= not hardReset;
  
  patterngenerator : PATTERN_GENERATOR
    port map (CLK                   => SYSCLK,
              DATA_IN(31 downto 0)  => LOCDATA(31 downto 0),
              enable                => XLXN_450,
              LOAD                  => TST_CNTR_WRT,
              RST                   => RESET,
              strt_exp              => START_EXP_DUMMY,
              DATA_OUT(31 downto 0) => TST_CNTR_DATA(31 downto 0),
              DATA_RDY              => TST_CNTR_REQ);

  PersonalityModule : Personality_ModuleV45
    port map (ADDRESS(15 downto 0)      => locaddr(15 downto 0),
              RESET                     => RESET,
              BOARD_SEL                 => LOCAL_SEL,
              CLOCKEN_REG(15 downto 0)  => XLXN_70(15 downto 0),
              DATA_IN(15 downto 0)      => LOCDATA(15 downto 0),
              ECHO_DATA_IN(31 downto 0) => XLXN_298(31 downto 0),
              ECHO_REQ                  => ECHO_REQ,
              LED_DATA(2 downto 0)      => XLXN_439(2 downto 0),
              MPU_EVENTS(15 downto 0)   => XLXN_466(15 downto 0),
              READ                      => READ_DECODE,
              READ_STROBE               => READ_STROBE,
              SEQ_CMD_REG(15 downto 0)  => XLXN_10(15 downto 0),
              SEQ_INT_CTR(31 downto 0)  => XLXN_214(31 downto 0),
              SEQ_INT_REG(31 downto 0)  => XLXN_12(31 downto 0),
              SEQ_LPP_REG(15 downto 0)  => XLXN_14(15 downto 0),
              SEQ_PAT_MEM(15 downto 0)  => XLXN_16(15 downto 0),
              SEQ_PGM_MEM(15 downto 0)  => XLXN_18(15 downto 0),
              SN_DATA(47 downto 0)      => SN_DATA(47 downto 0),
              STATUS_REG(15 downto 0)   => XLXN_19(15 downto 0),
              SYSCLK                    => SYSCLK,
              TEMP_DATA_IN(9 downto 0)  => XLXN_465(9 downto 0),
              TST_CTR_REG(31 downto 0)  => TST_CNTR_DATA(31 downto 0),
              TST_CTR_REQ               => TST_CNTR_REQ,
              WRITE                     => WRITE_DECODE,
              CLOCKEN_SEL               => CLKEN_SEL,
              CMD_OUT                   => LOCAL_CMD,
              CONTROL_OUT(15 downto 0)  => CTL_BUSS(15 downto 0),
              DATA_OUT(31 downto 0)     => dataOut,
--              EXPOSE_START              => open,
--              FRAME_START               => open,
              SYNCDEL_SEL               => syncDelayWrite,
              SYNCDEL_REG               => syncDelayReg,
              program_n                 => PROGRAM_N,
              LED_REG_SEL               => XLXN_438,
              SEQ_CMD_SEL               => XLXN_9,
              SEQ_INT_SEL               => XLXN_11,
              SEQ_LPP_SEL               => WR_LOOPREGS,
              SEQ_PAT_SEL               => XLXN_15,
              SYNC_OUT                  => syncOut,
              TEMP_RD_STB               => XLXN_464,
              TST_CTR_ENB               => XLXN_450,
              TST_CTR_WRT               => TST_CNTR_WRT,
              WRITE_STB                 => WRITE_STROBE);
  cmdRdy <= WRITE_STROBE and LOCAL_CMD;
  seqDataReq <= WRITE_STROBE and (not LOCAL_CMD);

  syncDelay_1: syncDelay
    port map (
      sysclk      => sysClk,
      reset       => reset,
      write       => syncDelayWrite,
      delayDatIn  => LOCDATA(7 downto 0),
      delayDatOut => syncDelayReg,
      delChipClk  => delChipClk,
      delChipD    => delChipD,
      delChipE    => delChipE);
  
  resetSync_1 : resetSync
    port map (
      reset     => reset,
      sysClk    => sysClk,
      syncRcvd  => SYNC_OKAY,
      asyncFlag => ASYNC_FLAG);

  SEQBUSMUX : Sequencer_Bus_Mux
    port map (CLK                           => SYSCLK,
              DHE_ADDRDATA_IN(31 downto 0)  => SEQ_ADDRDATA(31 downto 0),
              DHE_BOARD_SEL_IN(7 downto 0)  => BRDSEL(7 downto 0),
              DHE_BUS_REQ                   => SEQ_BUS_REQ,
              DHE_DEV_ADDR_IN(4 downto 0)   => SEQ_DEVADDR(4 downto 0),
              DHE_MODE_IN(1 downto 0)       => SEQ_MODE_SEL(1 downto 0),
              RST                           => RESET,
              SEQ_ADDRDATA_IN(31 downto 0)  => XLXN_43(31 downto 0),
              SEQ_BOARD_SEL_IN(6 downto 0)  => SEQ_CTL(24 downto 18),
              SEQ_BUS_REQ                   => MPU_BUS_REQ,
              SEQ_DEV_ADDR_IN(4 downto 0)   => SEQ_CTL(29 downto 25),
              SEQ_MODE_IN(1 downto 0)       => SEQ_CTL(31 downto 30),
              BUS_ADDRDATA_OUT(31 downto 0) => SEQ_DATA(31 downto 0),
              BUS_BOARD_SEL_OUT(8 downto 2) => BRD_SLCT_N(8 downto 2),
              BUS_DEV_ADDR_OUT(4 downto 0)  => DEV_ADDR(4 downto 0),
              BUS_MODE_OUT(1 downto 0)      => SEQ_MODE(1 downto 0),
              DHE_BUS_ACK                   => SEQ_BUS_ACK,
              SEQ_BUS_ACK                   => MPU_BUS_ACK);

  SERNUMIFC : serno_interface
    port map(
      clock     => sysclk,
      reset     => reset,
      sn_data   => SN_DATA(47 downto 0),
      sn_crc_ok => open,
      sn_io     => DQ
      );

  TEMPSENSORIFC : TempSensor
    port map (read_temp             => XLXN_464,
              sysclk                => SYSCLK,
              temp_dout             => TEMP_DOUT,
              temp_data(9 downto 0) => XLXN_465(9 downto 0),
              temp_din              => TEMP_DIN,
              temp_sclk             => TEMP_SCLK);

  XLXI_29 : BUF
    port map (I => SYNC_IN,
              O => DHE_SYNC_IN);


  FPGA_CTL_1_DUMMY <= PIX_WRT_N or LOCAL_SEL;

  READ_STROBE <= not PIX_WRT_N;



  RA_LINK_N <= RESET;

  XLXI_89 : BUF
    port map (I => START_EXP_DUMMY,
              O => FPGA_CTL_2);

  XLXI_90 : BUF
    port map (I => START_EXP_DUMMY,
              O => FPGA_CTL_6);


  
end BEHAVIORAL;
