-- ad7814arm.vhd
-- analog devices temp sensor device MODEL
-- jamieson olsen <jamieson@fnal.gov>
-- 2 May 2006

-- notes:
-- 1. power down state not supported, DIN input is not connected.
-- 2. CS_N must be used i.e. not tied to ground.

library ieee;
use ieee.std_logic_1164.all;
use ieee.numeric_std.all;

entity ad7814 is
  generic(temp : integer := 25);        -- temp range -55C to 125C
  port(
    sclk : in  std_logic;
    cs_n : in  std_logic;
    din  : in  std_logic;
    dout : out std_logic
    );
end ad7814;

architecture ad7814_arch of ad7814 is

  -- define signals...

  signal temp_int, bit_count : integer := 0;
  signal temp_vector         : std_logic_vector(11 downto 0);
  signal dout_temp           : std_logic;

  constant t4 : time := 35 ns;

  -- define registers...      

begin

  -- combinatorial stuff...

  temp_int    <= temp * 4;              -- convert temp to counts
  temp_vector <= "00"&std_logic_vector(to_signed(temp_int, 10));  -- convert counts to bits

  dout_temp <= temp_vector(bit_count) when (cs_n = '0') else 'Z';
  dout      <= dout_temp after t4;

  -- sequential stuff...

  process(sclk, cs_n)
  begin
    if (cs_n = '1') then
      bit_count <= 11;
    elsif falling_edge(sclk) then
      if (bit_count > 0) then
        bit_count <= bit_count-1;
      end if;
    end if;
  end process;


end ad7814_arch;
