-------------------------------------------------------------------------------
-- Title      : brd_mod
-- Project    : 
-------------------------------------------------------------------------------
-- File       : brd_mod.vhd
-- Author     :   <laia@PWLAIA>
-- Company    : 
-- Created    : 2008-12-04
-- Last update: 2008-12-09
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: module to simulate ACQ&Clock boards
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-12-04  1.0      laia    Created
-------------------------------------------------------------------------------
library ieee;
use ieee.std_logic_1164.all;


entity mcb_mod is
  
  port (
    sysclk    : in  std_logic;                      -- system clk
    board_sel : in  std_logic;                      -- active low
    seq_data  : in  std_logic_vector (31 downto 0);
    dev_addr  : in  std_logic_vector (4 downto 0);  -- register address for
    seq_mode  : in  std_logic_vector (1 downto 0);
    pix_data  : out std_logic_vector (47 downto 0)
    );

end mcb_mod;
architecture a of mcb_mod is
  signal tmp_pixdata : std_logic_vector(47 downto 0);
  signal writen_val  : std_logic_vector(31 downto 0);

  signal reset_n : std_logic;
begin  -- a

  -- purpose: when seq_mode = 00 do a reset
  -- type   : combinational
  -- inputs : clk
  -- outputs: reset_n
  mode_reset : process (board_sel, seq_mode)
  begin  -- process mode_reset
    if board_sel = '0' then
      if seq_mode = "00" then
        reset_n <= '0';
      else
        reset_n <= '1';
      end if;
    else
      reset_n <= '1';
    end if;
  end process mode_reset;

  -- output
  pix_data <= tmp_pixdata when board_sel = '0' else (others => 'Z');

  -- temp pixdata
  tmp_pixdata(47 downto 32) <= (others => '0');

  -- purpose: output equals last writen value or zeros
  -- type   : combinational
  -- inputs : a
  -- outputs: 
  mux : process (seq_mode, writen_val)
  begin  -- process mux
    case seq_mode is
      when "01" =>
        tmp_pixdata(31 downto 0) <= writen_val;
      when others => tmp_pixdata <= (others => '0');
    end case;
  end process mux;


  input_data : process (sysclk, reset_n)
  begin  -- process input_data
    if reset_n = '0' then               -- asynchronous reset (active low)
      writen_val <= (others => '0');
    elsif sysclk'event and sysclk = '1' then  -- rising clock edge
      if board_sel = '0' and seq_mode = "10" then
        writen_val <= seq_data;
      end if;
    end if;
  end process input_data;
  
  
end a;
