-------------------------------------------------------------------------------
-- Title      : Simple testbench for mcbfull_timesim
-- Project    : 
-------------------------------------------------------------------------------
-- File       : mcbfull_timesim_tb.vhd
-- Author     :   <otger@PWOTGER>
-- Company    : 
-- Created    : 2008-12-02
-- Last update: 2009-01-20
-- Platform   : 
-- Standard   : VHDL'87
-------------------------------------------------------------------------------
-- Description: 
-------------------------------------------------------------------------------
-- Copyright (c) 2008 
-------------------------------------------------------------------------------
-- Revisions  :
-- Date        Version  Author  Description
-- 2008-12-02  1.0      otger	Created
-------------------------------------------------------------------------------
library IEEE;
use IEEE.STD_LOGIC_1164.ALL;
--library SIMPRIM;
--use SIMPRIM.VCOMPONENTS.ALL;
--use SIMPRIM.VPACKAGE.ALL;

entity mcbfull_timesim_tb is
  
end mcbfull_timesim_tb;

architecture simulation of mcbfull_timesim_tb is
  component mcbFull
    port (
      sysclk       : in    std_logic;
      dq           : inout std_logic;
      led_seq      : out   std_logic;
      temp_sclk    : out   std_logic;
      temp_dout    : in    std_logic;
      temp_din     : out   std_logic;
      ra_link_n    : out   std_logic;
      program_n    : out   std_logic;
      fpga_ctl_6   : out   std_logic;
      tp_11        : out   std_logic;
      tp_12        : out   std_logic;
      tp_13        : out   std_logic;
      tp_14        : out   std_logic;
      tp_19        : out   std_logic;
      tp_20        : out   std_logic;
      tp_21        : out   std_logic;
      tp_22        : in    std_logic;
      board_slct_n : out   std_logic_vector(8 downto 2);
      seq_mode     : out   std_logic_vector(1 downto 0);
      dev_addr     : out   std_logic_vector(5 downto 0);
      seq_data     : out   std_logic_vector(31 downto 0);
      clk2         : out   std_logic;
      clk3         : out   std_logic;
      clk4         : out   std_logic;
      clk5         : out   std_logic;
      clk6         : out   std_logic;
      clk7         : out   std_logic;
      clk8         : out   std_logic;
      sync_in      : in    std_logic;
      sync_out     : out   std_logic;
      start_exp    : out   std_logic;
      pix_data     : in    std_logic_vector(47 downto 0);
      pipe_req_n   : in    std_logic_vector(6 downto 0);
      pipe_wrt_n   : in    std_logic;
      led_fib      : out   std_logic;
      clk1f0       : out   std_logic;
      clk1f1       : out   std_logic;
      clk2f0       : out   std_logic;
      clk2f1       : out   std_logic;
      scl          : out   std_logic;
      sda          : inout std_logic;
      exdat_in     : in    std_logic;
      exdat_out    : out   std_logic;
      uclk         : out   std_logic;
      ud           : out   std_logic_vector(31 downto 0);
      lrl          : in    std_logic_vector(3 downto 0);
      lff_n        : in    std_logic;
      utest_n      : out   std_logic;
      ldown_n      : in    std_logic;
      uwen_n       : out   std_logic;
      uctrl_n      : out   std_logic;
      ureset_n     : out   std_logic;
      ack_n        : in    std_logic_vector(8 downto 2);
      resetInHw_n  : in    std_logic;
      spr          : inout std_logic_vector(8 downto 0);
      temp_cs      : out   std_logic;
      delChipD     : out    std_logic;
      delChipE     : out   std_logic;
      delChipClk   : out   std_logic);
  end component;
  
  component gen_data
    generic (
      waitTicks : integer;
      lrlClkHT  : integer;
      wait2Start : integer);
    port (
      sysclk   : in  std_logic;
      reset_n  : in  std_logic;
      romDatIn : in  std_logic_vector(31 downto 0);
      romAddr  : out std_logic_vector(15 downto 0);
      romRd    : out std_logic;
      lrl      : out std_logic_vector(3 downto 0));
  end component;

  -- mcb_mod does not have reset because it is a seq bus command
  component mcb_mod
    port (
      sysclk    : in  std_logic;
      board_sel : in  std_logic;
      seq_data  : in  std_logic_vector (31 downto 0);
      dev_addr  : in  std_logic_vector (4 downto 0);
      seq_mode  : in  std_logic_vector (1 downto 0);
      pix_data  : out std_logic_vector (47 downto 0));
  end component;
  
  component ROM
    generic (
      load_file_name : string;
      datalength     : integer);
    port (
      sel     : in  std_logic;
      address : in  std_logic_vector;
      data    : out std_logic_vector(datalength - 1 downto 0));
  end component;

  signal romRd     : std_logic;
  signal romAddr : std_logic_vector(15 downto 0);
  signal romData    : std_logic_vector(31 downto 0);
  signal sysclk       : std_logic;
  signal dq           : std_logic;
  signal led_seq      : std_logic;
  signal temp_sclk    : std_logic;
  signal temp_dout    : std_logic;
  signal temp_din     : std_logic;
  signal ra_link_n    : std_logic;
  signal program_n    : std_logic;
  signal fpga_ctl_6   : std_logic;
  signal tp_11        : std_logic;
  signal tp_12        : std_logic;
  signal tp_13        : std_logic;
  signal tp_14        : std_logic;
  signal tp_19        : std_logic;
  signal tp_20        : std_logic;
  signal tp_21        : std_logic;
  signal tp_22        : std_logic;
  signal board_slct_n : std_logic_vector(8 downto 2);
  signal seq_mode     : std_logic_vector(1 downto 0);
  signal dev_addr     : std_logic_vector(5 downto 0);
  signal seq_data     : std_logic_vector(31 downto 0);
  signal clk2         : std_logic;
  signal clk3         : std_logic;
  signal clk4         : std_logic;
  signal clk5         : std_logic;
  signal clk6         : std_logic;
  signal clk7         : std_logic;
  signal clk8         : std_logic;
  signal sync_in      : std_logic;
  signal sync_out     : std_logic;
  signal start_exp    : std_logic;
  signal pix_data     : std_logic_vector(47 downto 0);
  signal pipe_req_n   : std_logic_vector(6 downto 0);
  signal pipe_wrt_n   : std_logic;
  signal led_fib      : std_logic;
  signal clk1f0       : std_logic;
  signal clk1f1       : std_logic;
  signal clk2f0       : std_logic;
  signal clk2f1       : std_logic;
  signal scl          : std_logic;
  signal sda          : std_logic;
  signal exdat_in     : std_logic;
  signal exdat_out    : std_logic;
  signal uclk         : std_logic;
  signal ud           : std_logic_vector(31 downto 0);
  signal lrl          : std_logic_vector(3 downto 0);
  signal lff_n        : std_logic;
  signal utest_n      : std_logic;
  signal ldown_n      : std_logic;
  signal uwen_n       : std_logic;
  signal uctrl_n      : std_logic;
  signal ureset_n     : std_logic;
  signal ack_n        : std_logic_vector(8 downto 2);
  signal resetInHw_n  : std_logic;
  signal spr          : std_logic_vector(8 downto 0);
  signal delay_din    : std_logic;
  signal temp_cs      : std_logic;
  signal delay_dout   : std_logic;
  signal delay_en     : std_logic;
  signal delay_clk    : std_logic;


begin  -- simulation


  -- purpose: generate sysclk
  -- type   : combinational
  -- inputs : 
  -- outputs: sysclk
  process
  begin  -- process
    sysclk <= '0';
    wait for 12.5 ns;
    sysclk <= '1';
    wait for 12.5 ns;
  end process;

  p_reset: process
  begin  -- process p_reset
    resetInHw_n <= '0';
    tp_22 <= '0';
    wait for 100 ns;
    resetInHw_n <= '1';
    tp_22 <= '1';
    wait;
  end process p_reset;

  sync_in <= sync_out;

  acquisition: mcb_mod
    port map (
      sysclk    => sysclk,
      board_sel => board_slct_n(6),
      seq_data  => seq_data,
      dev_addr  => dev_addr(4 downto 0),
      seq_mode  => seq_mode,
      pix_data  => pix_data);

  clocks: mcb_mod
    port map (
      sysclk    => sysclk,
      board_sel => board_slct_n(3),
      seq_data  => seq_data,
      dev_addr  => dev_addr(4 downto 0),
      seq_mode  => seq_mode,
      pix_data  => pix_data);

  ROM_1: ROM
    generic map (
      load_file_name => "RomCfgFile.txt",
--      load_file_name => "romDataFile.txt", 
      datalength     => 32)
    port map (
      sel     => romRd,
      address => romAddr,
      data    => romData);


  gen_data_1: gen_data
    generic map (
      waitTicks => 1500,
      lrlClkHT  => 24,
      wait2Start => 10000)
    port map (
      sysclk   => sysclk,
      reset_n  => resetInHw_n,
      romDatIn => romData,
      romAddr  => romAddr,
      romRd    => romRd,
      lrl      => lrl);

  mcbFull_1: mcbFull
    port map (
      sysclk       => sysclk,
      dq           => dq,
      led_seq      => led_seq,
      temp_sclk    => temp_sclk,
      temp_dout    => temp_dout,
      temp_din     => temp_din,
      ra_link_n    => ra_link_n,
      program_n    => program_n,
      fpga_ctl_6   => fpga_ctl_6,
      tp_11        => tp_11,
      tp_12        => tp_12,
      tp_13        => tp_13,
      tp_14        => tp_14,
      tp_19        => tp_19,
      tp_20        => tp_20,
      tp_21        => tp_21,
      tp_22        => tp_22,
      board_slct_n => board_slct_n,
      seq_mode     => seq_mode,
      dev_addr     => dev_addr,
      seq_data     => seq_data,
      clk2         => clk2,
      clk3         => clk3,
      clk4         => clk4,
      clk5         => clk5,
      clk6         => clk6,
      clk7         => clk7,
      clk8         => clk8,
      sync_in      => sync_in,
      sync_out     => sync_out,
      start_exp    => start_exp,
      pix_data     => pix_data,
      pipe_req_n   => pipe_req_n,
      pipe_wrt_n   => pipe_wrt_n,
      led_fib      => led_fib,
      clk1f0       => clk1f0,
      clk1f1       => clk1f1,
      clk2f0       => clk2f0,
      clk2f1       => clk2f1,
      scl          => scl,
      sda          => sda,
      exdat_in     => exdat_in,
      exdat_out    => exdat_out,
      uclk         => uclk,
      ud           => ud,
      lrl          => lrl,
      lff_n        => lff_n,
      utest_n      => utest_n,
      ldown_n      => ldown_n,
      uwen_n       => uwen_n,
      uctrl_n      => uctrl_n,
      ureset_n     => ureset_n,
      ack_n        => ack_n,
      resetInHw_n  => resetInHw_n,
      spr          => spr,
      delChipD     => delay_dout,
      temp_cs      => temp_cs,
      delChipE     => delay_en,
      delChipClk   => delay_clk);

  -----------------------------------------------------------------------------
  -- Signal assignments
  -----------------------------------------------------------------------------
  pipe_req_n <= (others => '1');
  pipe_wrt_n <= '1';

  ack_n <= (others => '1');
  lff_n <= '1';
  ldown_n <= '1';

end simulation;
