library ieee;
use ieee.std_logic_1164.all;
use ieee.std_logic_unsigned.all;

entity stackcomp is
end stackcomp;

architecture stackcomp_arch of stackcomp is

-- define signals...

  constant clock_period : time                          := 25 ns;
  signal   clock        : std_logic                     := '0';
  signal   addr         : std_logic_vector(5 downto 0)  := "000000";
  signal   wdata        : std_logic_vector(11 downto 0) := X"000";
  signal   we           : std_logic;
  signal   rdata_las    : std_logic_vector(11 downto 0);
  signal   rdata_ram64s : std_logic_vector(11 downto 0);
  signal   rdata_xor    : std_logic_vector(11 downto 0);

  component Loop_Addr_Stack
    port (LASPtr       : in  std_logic_vector(5 downto 0);
          LASWriteData : in  std_logic_vector(11 downto 0);
          LASWrite     : in  std_logic;
          LASRdData    : out std_logic_vector(11 downto 0);
          SysClk       : in  std_logic);
  end component;

  component RAM64S is
    generic(width : integer := 12);
    port(
      wclk : in  std_logic;
      we   : in  std_logic;
      a    : in  std_logic_vector(5 downto 0);
      d    : in  std_logic_vector((width-1) downto 0);
      o    : out std_logic_vector((width-1) downto 0)
      );
  end component;

begin

  clock <= not clock after clock_period/2;

  transactor : process
  begin
    addr  <= "000000";
    wdata <= X"F00";
    we    <= '0';

    wait for 100 ns;

    -- write stuff into the rams (sync)

    wait until falling_edge(clock);
    we <= '1';
    wait until falling_edge(clock);
    for i in 0 to 31 loop
      addr  <= addr + 1;
      wdata <= wdata + 1;
      wait until falling_edge(clock);
    end loop;

    we   <= '0';
    addr <= "000000";

    -- read stuff from the rams (async)

    wait for 232 ns;
    addr <= "000001";

    wait for 23 ns;
    addr <= "000101";

    wait for 9 ns;
    addr <= "000010";

    wait;

  end process transactor;

  process (rdata_las, rdata_ram64s)
  begin  -- process
    for i in 0 to 11 loop
      rdata_xor(i) <= rdata_las(i) xor rdata_ram64s(i);
    end loop;  -- i
  end process;

  oldram : Loop_Addr_Stack
    port map(LASPtr       => addr,
             LASWriteData => wdata,
             LASWrite     => we,
             LASRdData    => rdata_las,
             SysClk       => clock);

  newram : RAM64S
    generic map(width => 12)
    port map(
      wclk => clock,
      we   => we,
      a    => addr,
      d    => wdata,
      o    => rdata_ram64s
      );

end stackcomp_arch;
